@@ -1,24 +1,32 @@
 import logging
+import numpy as np
 
 import asdf
 from astropy import coordinates as coord
 from astropy import units as u
+from astropy.modeling import bind_bounding_box
 from astropy.modeling.models import Const1D, Mapping, Identity, Shift
 from astropy.modeling.bounding_box import CompoundBoundingBox
 import gwcs.coordinate_frames as cf
 from gwcs import wcs
 
-from .util import (not_implemented_mode, subarray_transform,
-                   velocity_correction, bounding_box_from_subarray,
-                   transform_bbox_from_shape)
+from stdatamodels.jwst.datamodels import ImageModel, NIRISSGrismModel, DistortionModel
+from stdatamodels.jwst.transforms.models import (
+    NirissSOSSModel,
+    NIRISSForwardRowGrismDispersion,
+    NIRISSBackwardGrismDispersion,
+    NIRISSForwardColumnGrismDispersion,
+)
+
+from .util import (
+    not_implemented_mode,
+    subarray_transform,
+    velocity_correction,
+    bounding_box_from_subarray,
+    transform_bbox_from_shape,
+)
 from . import pointing
-from ..transforms.models import (NirissSOSSModel,
-                                 NIRISSForwardRowGrismDispersion,
-                                 NIRISSBackwardGrismDispersion,
-                                 NIRISSForwardColumnGrismDispersion)
-from ..datamodels import ImageModel, NIRISSGrismModel, DistortionModel
-from stdatamodels import s3_utils
-from ..lib.reffile_utils import find_row
+from jwst.lib.reffile_utils import find_row
 
 log = logging.getLogger(__name__)
 log.setLevel(logging.DEBUG)
@@ -27,23 +35,22 @@ __all__ = ["create_pipeline", "imaging", "niriss_soss", "niriss_soss_set_input",
 
 
 def create_pipeline(input_model, reference_files):
-    """Create the WCS pipeline based on EXP_TYPE.
+    """
+    Create the WCS pipeline based on EXP_TYPE.
 
     Parameters
     ----------
-    input_model : `~jwst.datamodel.DataModel`
-        Input datamodel for processing
+    input_model : JwstDataModel
+        The input data model.
     reference_files : dict
-        The dictionary of reference file names and their associated files
-        {reftype: reference file name}.
+        Mapping between reftype (keys) and reference file name (vals).
 
     Returns
     -------
     pipeline : list
-        The pipeline list that is returned is suitable for
-        input into  gwcs.wcs.WCS to create a GWCS object.
+        The WCS pipeline, suitable for input into `gwcs.WCS`.
     """
-    log.debug(f'reference files used in NIRISS WCS pipeline: {reference_files}')
+    log.debug(f"reference files used in NIRISS WCS pipeline: {reference_files}")
     exp_type = input_model.meta.exposure.type.lower()
     pipeline = exp_type2transform[exp_type](input_model, reference_files)
 
@@ -52,45 +59,46 @@ def create_pipeline(input_model, reference_files):
 
 def niriss_soss_set_input(model, order_number):
     """
-    Extract a WCS fr a specific spectral order.
+    Extract a WCS for a specific spectral order.
 
     Parameters
     ----------
     model : `~jwst.datamodels.ImageModel`
         An instance of an ImageModel
     order_number : int
-        the spectral order
+        The spectral order
 
     Returns
     -------
-    WCS - the WCS corresponding to the spectral order.
-
+    gwcs.WCS
+        The WCS corresponding to the spectral order.
     """
-
     # Make sure the spectral order is available.
     if order_number < 1 or order_number > 3:
-        raise ValueError('Order must be between 1 and 3')
+        raise ValueError("Order must be between 1 and 3")
 
     # Return the correct transform based on the order_number
     obj = model.meta.wcs.forward_transform.get_model(order_number)
 
     # use the size of the input subarray
-    detector = cf.Frame2D(name='detector', axes_order=(0, 1), unit=(u.pix, u.pix))
-    spec = cf.SpectralFrame(name='spectral', axes_order=(2,), unit=(u.micron,),
-                            axes_names=('wavelength',))
-    sky = cf.CelestialFrame(reference_frame=coord.ICRS(),
-                            axes_names=('ra', 'dec'),
-                            axes_order=(0, 1), unit=(u.deg, u.deg), name='sky')
-    world = cf.CompositeFrame([sky, spec], name='world')
-    pipeline = [(detector, obj),
-                (world, None)
-                ]
+    detector = cf.Frame2D(name="detector", axes_order=(0, 1), unit=(u.pix, u.pix))
+    spec = cf.SpectralFrame(
+        name="spectral", axes_order=(2,), unit=(u.micron,), axes_names=("wavelength",)
+    )
+    sky = cf.CelestialFrame(
+        reference_frame=coord.ICRS(),
+        axes_names=("ra", "dec"),
+        axes_order=(0, 1),
+        unit=(u.deg, u.deg),
+        name="sky",
+    )
+    world = cf.CompositeFrame([sky, spec], name="world")
+    pipeline = [(detector, obj), (world, None)]
 
     return wcs.WCS(pipeline)
 
 
 def _niriss_order_bounding_box(input_model, order):
-    import numpy as np
     bbox_y = np.array([-0.5, input_model.meta.subarray.ysize - 0.5])
     bbox_x = np.array([-0.5, input_model.meta.subarray.xsize - 0.5])
 
@@ -101,42 +109,51 @@ def _niriss_order_bounding_box(input_model, order):
     elif order == 3:
         return tuple(bbox_y), tuple(bbox_x)
     else:
-        raise ValueError(f'Invalid spectral order: {order} provided. Spectral order must be 1, 2, or 3.')
+        raise ValueError(
+            f"Invalid spectral order: {order} provided. Spectral order must be 1, 2, or 3."
+        )
 
 
 def niriss_bounding_box(input_model):
-    bbox = {(order,): _niriss_order_bounding_box(input_model, order)
-            for order in [1, 2, 3]}
+    """
+    Create a bounding box for the NIRISS model.
+
+    Parameters
+    ----------
+    input_model : JwstDataModel
+        The input datamodel.
+
+    Returns
+    -------
+    CompoundBoundingBox
+        The bounding box for the NIRISS model.
+    """
+    bbox = {(order,): _niriss_order_bounding_box(input_model, order) for order in [1, 2, 3]}
     model = input_model.meta.wcs.forward_transform
-    return CompoundBoundingBox.validate(model, bbox, slice_args=[('spectral_order', True)], order='F')
+    return CompoundBoundingBox.validate(
+        model, bbox, slice_args=[("spectral_order", True)], order="F"
+    )
 
 
 def niriss_soss(input_model, reference_files):
     """
-    The NIRISS SOSS WCS pipeline.
+    Create the WCS pipeline for NIRISS SOSS data.
+
+    It includes TWO coordinate frames - "detector" and "world".
 
     Parameters
     ----------
-    input_model : `~jwst.datamodel.DataModel`
-        Input datamodel for processing
+    input_model : ImageModel, IFUImageModel, or CubeModel
+        The input data model.
     reference_files : dict
-        The dictionary of reference file names and their associated files
-        {reftype: reference file name}.
+        Mapping between reftype (keys) and reference file name (vals).
+        Requires 'specwcs' reference file.
 
     Returns
     -------
     pipeline : list
-        The pipeline list that is returned is suitable for
-        input into  gwcs.wcs.WCS to create a GWCS object.
-
-    Notes
-    -----
-    It includes tWO coordinate frames -
-    "detector" and "world".
-
-    It uses the "specwcs" reference file.
+        The WCS pipeline, suitable for input into `gwcs.WCS`.
     """
-
     # Get the target RA and DEC, they will be used for setting the WCS RA
     # and DEC based on a conversation with Kevin Volk.
     try:
@@ -144,31 +161,35 @@ def niriss_soss(input_model, reference_files):
         target_dec = float(input_model.meta.target.dec)
     except TypeError:
         # There was an error getting the target RA and DEC, so we are not going to continue.
-        raise ValueError('Problem getting the TARG_RA or TARG_DEC from input model {}'.format(input_model))
+        raise ValueError(
+            f"Problem getting the TARG_RA or TARG_DEC from input model {input_model}"
+        ) from None
 
     # Define the frames
-    detector = cf.Frame2D(name='detector', axes_order=(0, 1), unit=(u.pix, u.pix))
-    spec = cf.SpectralFrame(name='spectral', axes_order=(2,), unit=(u.micron,),
-                            axes_names=('wavelength',))
-    sky = cf.CelestialFrame(reference_frame=coord.ICRS(),
-                            axes_names=('ra', 'dec'),
-                            axes_order=(0, 1), unit=(u.deg, u.deg), name='sky')
-    world = cf.CompositeFrame([sky, spec], name='world')
+    detector = cf.Frame2D(name="detector", axes_order=(0, 1), unit=(u.pix, u.pix))
+    spec = cf.SpectralFrame(
+        name="spectral", axes_order=(2,), unit=(u.micron,), axes_names=("wavelength",)
+    )
+    sky = cf.CelestialFrame(
+        reference_frame=coord.ICRS(),
+        axes_names=("ra", "dec"),
+        axes_order=(0, 1),
+        unit=(u.deg, u.deg),
+        name="sky",
+    )
+    world = cf.CompositeFrame([sky, spec], name="world")
 
     try:
-        # We'd like to open this file as a DataModel, so we can consolidate
-        # the S3 URI handling to one place.  The S3-related code here can
-        # be removed once we have a specwcs DataModel subclass.
-        if s3_utils.is_s3_uri(reference_files['specwcs']):
-            bytesio_or_path = s3_utils.get_object(reference_files['specwcs'])
-        else:
-            bytesio_or_path = reference_files['specwcs']
+        bytesio_or_path = reference_files["specwcs"]
+
         with asdf.open(bytesio_or_path) as af:
             wl1 = af.tree[1].copy()
             wl2 = af.tree[2].copy()
             wl3 = af.tree[3].copy()
     except Exception as e:
-        raise IOError(f"Error reading wavelength correction from {reference_files['specwcs']}") from e
+        raise OSError(
+            f"Error reading wavelength correction from {reference_files['specwcs']}"
+        ) from e
 
     velosys = input_model.meta.wcsinfo.velosys
     if velosys is not None:
@@ -180,15 +201,17 @@ def niriss_soss(input_model, reference_files):
 
     # Reverse the order of inputs passed to Tabular because it's in python order in modeling.
     # Consider changing it in modeling ?
+    # fmt: off
     cm_order1 = (Mapping((0, 1, 1, 0)) |
-                 (Const1D(target_ra) & Const1D(target_dec) & wl1)
-                 ).rename('Order1')
+        (Const1D(target_ra) & Const1D(target_dec) & wl1)
+        ).rename("Order1")
     cm_order2 = (Mapping((0, 1, 1, 0)) |
-                 (Const1D(target_ra) & Const1D(target_dec) & wl2)
-                 ).rename('Order2')
+        (Const1D(target_ra) & Const1D(target_dec) & wl2)
+        ).rename("Order2")
     cm_order3 = (Mapping((0, 1, 1, 0)) |
-                 (Const1D(target_ra) & Const1D(target_dec) & wl3)
-                 ).rename('Order3')
+        (Const1D(target_ra) & Const1D(target_dec) & wl3)
+        ).rename("Order3")
+    # fmt: on
 
     subarray2full = subarray_transform(input_model)
     if subarray2full is not None:
@@ -196,55 +219,52 @@ def niriss_soss(input_model, reference_files):
         cm_order2 = subarray2full | cm_order2
         cm_order3 = subarray2full | cm_order3
 
-        bbox = ((-0.5, input_model.meta.subarray.ysize - 0.5),
-                (-0.5, input_model.meta.subarray.xsize - 0.5))
-        cm_order1.bounding_box = bbox
-        cm_order2.bounding_box = bbox
-        cm_order3.bounding_box = bbox
+        bbox = (
+            (-0.5, input_model.meta.subarray.xsize - 0.5),
+            (-0.5, input_model.meta.subarray.ysize - 0.5),
+        )
+        bind_bounding_box(cm_order1, bbox, order="F")
+        bind_bounding_box(cm_order2, bbox, order="F")
+        bind_bounding_box(cm_order3, bbox, order="F")
 
     # Define the transforms, they should accept (x,y) and return (ra, dec, lambda)
-    soss_model = NirissSOSSModel([1, 2, 3],
-                                 [cm_order1, cm_order2, cm_order3]
-                                 ).rename('3-order SOSS Model')
+    soss_model = NirissSOSSModel([1, 2, 3], [cm_order1, cm_order2, cm_order3]).rename(
+        "3-order SOSS Model"
+    )
 
     # Define the pipeline based on the frames and models above.
-    pipeline = [(detector, soss_model),
-                (world, None)
-                ]
+    pipeline = [(detector, soss_model), (world, None)]
 
     return pipeline
 
 
 def imaging(input_model, reference_files):
     """
-    The NIRISS imaging WCS pipeline.
+    Create the WCS pipeline for NIRISS imaging data.
+
+    It includes three coordinate frames - "detector" "v2v3" and "world".
 
     Parameters
     ----------
-    input_model : `~jwst.datamodel.DataModel`
-        Input datamodel for processing
+    input_model : ImageModel
+        The input data model.
     reference_files : dict
-        The dictionary of reference file names and their associated files
-        {reftype: reference file name}.
+        Mapping between reftype (keys) and reference file name (vals).
+        Requires 'distortion' reference file.
 
     Returns
     -------
     pipeline : list
-        The pipeline list that is returned is suitable for
-        input into  gwcs.wcs.WCS to create a GWCS object.
-
-    Notes
-    -----
-    It includes three coordinate frames -
-    "detector" "v2v3" and "world".
-    It uses the "distortion" reference file.
+        The WCS pipeline, suitable for input into `gwcs.WCS`.
     """
-    detector = cf.Frame2D(name='detector', axes_order=(0, 1), unit=(u.pix, u.pix))
-    v2v3 = cf.Frame2D(name='v2v3', axes_order=(0, 1), axes_names=('v2', 'v3'),
-                      unit=(u.arcsec, u.arcsec))
-    v2v3vacorr = cf.Frame2D(name='v2v3vacorr', axes_order=(0, 1),
-                            axes_names=('v2', 'v3'), unit=(u.arcsec, u.arcsec))
-    world = cf.CelestialFrame(reference_frame=coord.ICRS(), name='world')
+    detector = cf.Frame2D(name="detector", axes_order=(0, 1), unit=(u.pix, u.pix))
+    v2v3 = cf.Frame2D(
+        name="v2v3", axes_order=(0, 1), axes_names=("v2", "v3"), unit=(u.arcsec, u.arcsec)
+    )
+    v2v3vacorr = cf.Frame2D(
+        name="v2v3vacorr", axes_order=(0, 1), axes_names=("v2", "v3"), unit=(u.arcsec, u.arcsec)
+    )
+    world = cf.CelestialFrame(reference_frame=coord.ICRS(), name="world")
 
     distortion = imaging_distortion(input_model, reference_files)
 
@@ -252,42 +272,44 @@ def imaging(input_model, reference_files):
     va_corr = pointing.dva_corr_model(
         va_scale=input_model.meta.velocity_aberration.scale_factor,
         v2_ref=input_model.meta.wcsinfo.v2_ref,
-        v3_ref=input_model.meta.wcsinfo.v3_ref
+        v3_ref=input_model.meta.wcsinfo.v3_ref,
     )
 
     subarray2full = subarray_transform(input_model)
     if subarray2full is not None:
         distortion = subarray2full | distortion
-        distortion.bounding_box = bounding_box_from_subarray(input_model)
+
+        # Bind the bounding box to the distortion model using the bounding box ordering
+        # used by GWCS. This makes it clear the bounding box is set correctly to GWCS
+        bind_bounding_box(distortion, bounding_box_from_subarray(input_model, order="F"), order="F")
 
     tel2sky = pointing.v23tosky(input_model)
-    pipeline = [(detector, distortion),
-                (v2v3, va_corr),
-                (v2v3vacorr, tel2sky),
-                (world, None)]
+    pipeline = [(detector, distortion), (v2v3, va_corr), (v2v3vacorr, tel2sky), (world, None)]
     return pipeline
 
 
 def imaging_distortion(input_model, reference_files):
-    """ Create the transform from "detector" to "v2v3".
+    """
+    Create the transform from "detector" to "v2v3".
 
     Parameters
     ----------
-    input_model : `~jwst.datamodel.DataModel`
-        Input datamodel for processing
+    input_model : ImageModel
+        The input data model.
     reference_files : dict
-        The dictionary of reference file names and their associated files.
+        Mapping between reftype (keys) and reference file name (vals).
+        Requires 'distortion' and filteroffset' reference files.
 
     Returns
     -------
-    The transform model
-
+    distortion : `astropy.modeling.Model`
+        The transform from "detector" to "v2v3".
     """
-    dist = DistortionModel(reference_files['distortion'])
+    dist = DistortionModel(reference_files["distortion"])
     distortion = dist.model
 
     try:
-        bbox = distortion.bounding_box
+        bbox = distortion.bounding_box.bounding_box(order="F")
     except NotImplementedError:
         # Check if the transform in the reference file has a ``bounding_box``.
         # If not set a ``bounding_box`` equal to the size of the image after
@@ -296,27 +318,32 @@ def imaging_distortion(input_model, reference_files):
     dist.close()
 
     # Add an offset for the filter
-    if reference_files['filteroffset'] is not None:
+    if reference_files["filteroffset"] is not None:
         obsfilter = input_model.meta.instrument.filter
         obspupil = input_model.meta.instrument.pupil
-        with asdf.open(reference_files['filteroffset']) as filter_offset:
-            filters = filter_offset.tree['filters']
+        with asdf.open(reference_files["filteroffset"]) as filter_offset:
+            filters = filter_offset.tree["filters"]
 
-        match_keys = {'filter': obsfilter, 'pupil': obspupil}
+        match_keys = {"filter": obsfilter, "pupil": obspupil}
         row = find_row(filters, match_keys)
         if row is not None:
-            col_offset = row.get('column_offset', 'N/A')
-            row_offset = row.get('row_offset', 'N/A')
+            col_offset = row.get("column_offset", "N/A")
+            row_offset = row.get("row_offset", "N/A")
             log.info(f"Offsets from filteroffset file are {col_offset}, {row_offset}")
 
-            if col_offset != 'N/A' and row_offset != 'N/A':
+            if col_offset != "N/A" and row_offset != "N/A":
                 distortion = Shift(col_offset) & Shift(row_offset) | distortion
         else:
             log.debug("No match in fitleroffset file.")
-    if bbox is None:
-        distortion.bounding_box = transform_bbox_from_shape(input_model.data.shape)
-    else:
-        distortion.bounding_box = bbox
+
+    # Bind the bounding box to the distortion model using the bounding box ordering used by GWCS.
+    # This makes it clear the bounding box is set correctly to GWCS
+    bind_bounding_box(
+        distortion,
+        transform_bbox_from_shape(input_model.data.shape, order="F") if bbox is None else bbox,
+        order="F",
+    )
+
     return distortion
 
 
@@ -326,24 +353,19 @@ def wfss(input_model, reference_files):
 
     Parameters
     ----------
-    input_model: `~jwst.datamodels.ImagingModel`
-        The input datamodel, derived from datamodels
-    reference_files: dict
-        Dictionary specifying reference file names
+    input_model : ImageModel
+        The input data model.
+    reference_files : dict
+        Mapping between reftype (keys) and reference file name (vals).
+        Requires 'distortion' and 'specwcs' reference files.
 
     Returns
     -------
     pipeline : list
-        The pipeline list that is returned is suitable for
-        input into  gwcs.wcs.WCS to create a GWCS object.
+        The WCS pipeline, suitable for input into `gwcs.WCS`.
 
     Notes
     -----
-    reference_files = {
-        "specwcs": 'GR150C_F090W.asdf'
-        "distortion": 'NIRISS_FULL_distortion.asdf'
-        }
-
     The tree in the grism reference file has a section for each order/beam as
     well as the link to the filter data file, not sure if there will be a
     separate passband reference file needed for the wavelength scaling or the
@@ -382,27 +404,30 @@ def wfss(input_model, reference_files):
     which contains the filter names.
 
     Source catalog use moved to extract_2d.
-
     """
-
     # The input is the grism image
     if not isinstance(input_model, ImageModel):
-        raise TypeError('The input data model must be an ImageModel.')
+        raise TypeError("The input data model must be an ImageModel.")
 
     # make sure this is a grism image
     if "NIS_WFSS" != input_model.meta.exposure.type:
-        raise ValueError('The input exposure is not NIRISS grism')
+        raise ValueError("The input exposure is not NIRISS grism")
 
     # Create the empty detector as a 2D coordinate frame in pixel units
-    gdetector = cf.Frame2D(name='grism_detector', axes_order=(0, 1),
-                           axes_names=('x_grism', 'y_grism'), unit=(u.pix, u.pix))
-    spec = cf.SpectralFrame(name='spectral', axes_order=(2,), unit=(u.micron,),
-                            axes_names=('wavelength',))
+    gdetector = cf.Frame2D(
+        name="grism_detector",
+        axes_order=(0, 1),
+        axes_names=("x_grism", "y_grism"),
+        unit=(u.pix, u.pix),
+    )
+    spec = cf.SpectralFrame(
+        name="spectral", axes_order=(2,), unit=(u.micron,), axes_names=("wavelength",)
+    )
 
     # translate the x,y detector-in to x,y detector out coordinates
     # Get the disperser parameters which are defined as a model for each
     # spectral order
-    with NIRISSGrismModel(reference_files['specwcs']) as f:
+    with NIRISSGrismModel(reference_files["specwcs"]) as f:
         dispx = f.dispx
         dispy = f.dispy
         displ = f.displ
@@ -413,33 +438,26 @@ def wfss(input_model, reference_files):
     # This is the actual rotation from the input model
     fwcpos = input_model.meta.instrument.filter_position
     if fwcpos is None:
-        raise ValueError('FWCPOS keyword value not found in input image')
+        raise ValueError("FWCPOS keyword value not found in input image")
 
     # sep the row and column grism models
     # In "DMS" orientation (same parity as the sky), the GR150C spectra
     # are aligned more closely with the rows, and the GR150R spectra are
     # aligned more closely with the columns.
-    if input_model.meta.instrument.filter.endswith('C'):
-        det2det = NIRISSForwardRowGrismDispersion(orders,
-                                                  lmodels=displ,
-                                                  xmodels=dispx,
-                                                  ymodels=dispy,
-                                                  theta=fwcpos - fwcpos_ref)
-    elif input_model.meta.instrument.filter.endswith('R'):
-        det2det = NIRISSForwardColumnGrismDispersion(orders,
-                                                     lmodels=displ,
-                                                     xmodels=dispx,
-                                                     ymodels=dispy,
-                                                     theta=fwcpos - fwcpos_ref)
+    if input_model.meta.instrument.filter.endswith("C"):
+        det2det = NIRISSForwardRowGrismDispersion(
+            orders, lmodels=displ, xmodels=dispx, ymodels=dispy, theta=fwcpos - fwcpos_ref
+        )
+    elif input_model.meta.instrument.filter.endswith("R"):
+        det2det = NIRISSForwardColumnGrismDispersion(
+            orders, lmodels=displ, xmodels=dispx, ymodels=dispy, theta=fwcpos - fwcpos_ref
+        )
     else:
-        raise ValueError("FILTER keyword {} is not valid."
-                         .format(input_model.meta.instrument.filter))
+        raise ValueError(f"FILTER keyword {input_model.meta.instrument.filter} is not valid.")
 
-    backward = NIRISSBackwardGrismDispersion(orders,
-                                             lmodels=invdispl,
-                                             xmodels=dispx,
-                                             ymodels=dispy,
-                                             theta=-(fwcpos - fwcpos_ref))
+    backward = NIRISSBackwardGrismDispersion(
+        orders, lmodels=invdispl, xmodels=dispx, ymodels=dispy, theta=-(fwcpos - fwcpos_ref)
+    )
     det2det.inverse = backward
 
     # Add in the wavelength shift from the velocity dispersion
@@ -449,7 +467,7 @@ def wfss(input_model, reference_files):
         pass
     if velosys is not None:
         velocity_corr = velocity_correction(input_model.meta.wcsinfo.velosys)
-        log.info("Added Barycentric velocity correction: {}".format(velocity_corr[1].amplitude.value))
+        log.info(f"Added Barycentric velocity correction: {velocity_corr[1].amplitude.value}")
         det2det = det2det | Mapping((0, 1, 2, 3)) | Identity(2) & velocity_corr & Identity(1)
 
     # create the pipeline to construct a WCS object for the whole image
@@ -474,26 +492,27 @@ def wfss(input_model, reference_files):
 
     imagepipe = []
     world = image_pipeline.pop()[0]
-    world.name = 'sky'
+    world.name = "sky"
     for cframe, trans in image_pipeline:
         trans = trans & (Identity(2))
         name = cframe.name
-        cframe.name = name + 'spatial'
+        cframe.name = name + "spatial"
         spatial_and_spectral = cf.CompositeFrame([cframe, spec], name=name)
         imagepipe.append((spatial_and_spectral, trans))
-    imagepipe.append((cf.CompositeFrame([world, spec], name='world'), None))
+    imagepipe.append((cf.CompositeFrame([world, spec], name="world"), None))
     grism_pipeline.extend(imagepipe)
 
     return grism_pipeline
 
 
-exp_type2transform = {'nis_image': imaging,
-                      'nis_wfss': wfss,
-                      'nis_soss': niriss_soss,
-                      'nis_ami': imaging,
-                      'nis_tacq': imaging,
-                      'nis_taconfirm': imaging,
-                      'nis_focus': imaging,
-                      'nis_dark': not_implemented_mode,
-                      'nis_lamp': not_implemented_mode,
-                      }
+exp_type2transform = {
+    "nis_image": imaging,
+    "nis_wfss": wfss,
+    "nis_soss": niriss_soss,
+    "nis_ami": imaging,
+    "nis_tacq": imaging,
+    "nis_taconfirm": imaging,
+    "nis_focus": imaging,
+    "nis_dark": not_implemented_mode,
+    "nis_lamp": not_implemented_mode,
+}
