@@ -5,11 +5,10 @@ import warnings
 from astropy.modeling import models
 from astropy import units as u
 import pytest
-from stdatamodels.validate import ValidationWarning
 
-from jwst.datamodels import DistortionModel, ReferenceFileModel
-from jwst.datamodels import wcs_ref_models
-from jwst.datamodels.wcs_ref_models import _SimpleModel
+from stdatamodels.exceptions import ValidationWarning
+from stdatamodels.jwst.datamodels import DistortionModel, ReferenceFileModel, wcs_ref_models
+from stdatamodels.jwst.datamodels.wcs_ref_models import _SimpleModel
 
 
 def find_all_wcs_ref_models_classes():
@@ -48,9 +47,9 @@ def distortion_model():
     return dist
 
 
-def test_distortion_schema(distortion_model, tmpdir):
+def test_distortion_schema(distortion_model, tmp_path):
     """Make sure DistortionModel roundtrips"""
-    path = str(tmpdir.join("test_dist.asdf"))
+    path = tmp_path / "test_dist.asdf"
     dist = distortion_model
     dist.save(path)
 
