@@ -1,18 +1,24 @@
-"""Callback registry"""
+"""
+Callback registry.
+
+This registry stores events which may be triggered on
+an AssociationRegistry given some signal; for instance,
+finalization of associations.
+"""
 
 from jwst.lib.signal_slot import Signal
 
-__all__ = ['CallbackRegistry']
+__all__ = ["CallbackRegistry"]
 
 
-class CallbackRegistry():
-    """Callback registry"""
+class CallbackRegistry:
+    """Callback registry."""
 
     def __init__(self):
-        self.registry = dict()
+        self.registry = {}
 
     def add(self, event, callback):
-        """Add a callback to an event"""
+        """Add a callback to an event."""
         try:
             signal = self.registry[event]
         except KeyError:
@@ -21,19 +27,19 @@ class CallbackRegistry():
         self.registry[event] = signal
 
     def reduce(self, event, *args):
-        """Perform a reduction on the event args
+        """
+        Perform a reduction on the event args.
 
         Parameters
         ----------
-        args : [arg[,...]]
+        *args : [arg[,...]]
             The args to filter
 
         Returns
         -------
-        The reduced results.
-        If no results can be determined,
-        such as if no callbacks were registered,
-        `None` is returned.
+        list, dict or None
+            The reduced results; if no results can be determined,
+            such as if no callbacks were registered, `None` is returned.
 
         Notes
         -----
@@ -45,22 +51,29 @@ class CallbackRegistry():
         There is no guarantee on order which the registered
         callbacks are made. Currently, the callbacks are in a list.
         Hence, the callbacks will be called in the order registered.
-
         """
         result = self.registry[event].reduce(*args)
         return result
 
     def add_decorator(self, event):
-        """Add callbacks by decoration
+        """
+        Add callbacks by decoration.
 
         Parameters
         ----------
         event : str
             The name of event to attach the object to.
+
+        Returns
+        -------
+        decorator
+            The decorator attached to the provided event name.
         """
+
         def decorator(func):
             self.add(event, func)
             return func
+
         return decorator
 
     __call__ = add_decorator
