@@ -1,26 +1,21 @@
-"""Constraints
-"""
+"""Constraints - use these to define the rules governing association candidate types."""
+
 import abc
 import collections
 from copy import deepcopy
 from itertools import chain
 import logging
 import re
-import typing
 
 from .process_list import ListCategory, ProcessList
-from .utilities import (
-    evaluate,
-    getattr_from_list,
-    is_iterable
-)
-from ..pool import PoolRow
+from .utilities import evaluate, getattr_from_list, is_iterable
+from jwst.associations.pool import PoolRow
 
 __all__ = [
-    'AttrConstraint',
-    'Constraint',
-    'ConstraintTrue',
-    'SimpleConstraint',
+    "AttrConstraint",
+    "Constraint",
+    "ConstraintTrue",
+    "SimpleConstraint",
 ]
 
 # Configure logging
@@ -29,12 +24,13 @@ logger.addHandler(logging.NullHandler())
 
 
 class SimpleConstraintABC(abc.ABC):
-    """Simple Constraint ABC
+    """
+    Simple Constraint ABC.
 
     Parameters
     ----------
     init : dict
-        dict where the key:value pairs define
+        Dictionary where the key:value pairs define
         the following parameters
 
     value : object or None
@@ -48,28 +44,69 @@ class SimpleConstraintABC(abc.ABC):
 
     Attributes
     ----------
+    found_values : set(str[,...])
+        Set of actual found values for this condition. True SimpleConstraints
+        do not normally set this; the value is not different than `value`.
+
     matched : bool
         Last call to `check_and_set`
     """
 
     # Attributes to show in the string representation.
-    _str_attrs = ('name', 'value')
+    _str_attrs: tuple = ("name", "value")
+
+    def __new__(cls, *args, **kwargs):  # noqa: ARG003
+        """
+        Force creation of the constraint attribute dict before anything else.
+
+        Returns
+        -------
+        ~jwst.associations.lib.constraint.SimpleConstraintABC
+            New instance of class.
+        """
+        obj = super().__new__(cls)
+        obj._ca_history = collections.deque()  # noqa: SLF001
+        obj._constraint_attributes = {}  # noqa: SLF001
+        return obj
 
     def __init__(self, init=None, value=None, name=None, **kwargs):
-
         # Defined attributes
         self.value = value
         self.name = name
         self.matched = False
+        self.found_values = set()
 
         if init is not None:
-            self.__dict__.update(init)
+            self._constraint_attributes.update(init)
         else:
-            self.__dict__.update(kwargs)
+            self._constraint_attributes.update(kwargs)
+
+    def __getattr__(self, name):
+        """
+        Retrieve user defined attribute.
+
+        Returns
+        -------
+        any
+            Attribute corresponding to provided name.
+        """
+        if name.startswith("_"):
+            return super().__getattribute__(name)
+        if name in self._constraint_attributes:
+            return self._constraint_attributes[name]
+        raise AttributeError(f"No such attribute {name}")
+
+    def __setattr__(self, name, value):
+        """Store all attributes in the user dictionary."""
+        if not name.startswith("_"):
+            self._constraint_attributes[name] = value
+        else:
+            object.__setattr__(self, name, value)
 
     @abc.abstractmethod
     def check_and_set(self, item):
-        """Check and set the constraint
+        """
+        Check and set the constraint.
 
         Returns
         -------
@@ -80,11 +117,13 @@ class SimpleConstraintABC(abc.ABC):
                 - List of `~jwst.associations.ProcessList`.
         """
         self.matched = True
+        self.found_values.add(self.value)
         return self.matched, []
 
     @property
-    def dup_names(self): #  -> dict[str, list[typing.Union[SimpleConstraint, Constraint]]]
-        """Return dictionary of constraints with duplicate names
+    def dup_names(self):
+        """
+        Return dictionary of constraints with duplicate names.
 
         This method is meant to be overridden by classes
         that need to traverse a list of constraints.
@@ -99,148 +138,129 @@ class SimpleConstraintABC(abc.ABC):
 
     @property
     def id(self):
-        """Return identifyer for the constraint
+        """
+        Return identifier for the constraint.
 
         Returns
         -------
         id : str
-            The identifyer
+            The identifier
         """
-        return f'{self.__class__.__name__}:{self.name}'
+        return f"{self.__class__.__name__}:{self.name}"
 
     def copy(self):
-        """Copy ourselves"""
+        """
+        Copy self.
+
+        Returns
+        -------
+        object
+            Deepcopy of self.
+        """
         return deepcopy(self)
 
-    def get_all_attr(self, attribute: str): # -> list[tuple[SimpleConstraint, typing.Any]]:
-        """Return the specified attribute
+    def get_all_attr(self, attribute, name=None):
+        """
+        Return the specified attribute.
 
-        This method is meant to be overridden by classes
-        that need to traverse a list of constraints.
+        This method exists solely to support `Constraint.get_all_attr`.
+        This obviates the need for class/method checking.
 
         Parameters
         ----------
         attribute : str
             The attribute to retrieve
 
+        name : str or None
+            Only return attribute if the name of the current constraint
+            matches the requested named constraints. If None, always
+            return value.
+
         Returns
         -------
         [(self, value)] : [(SimpleConstraint, object)]
             The value of the attribute in a tuple. If there is no attribute,
             an empty tuple is returned.
         """
-        value = getattr(self, attribute)
-        if value is not None:
-            return [(self, value)]
+        if name is None or name == self.name:
+            value = getattr(self, attribute, None)
+            if value is not None:
+                if not isinstance(value, (list, set)) or len(value):
+                    return [(self, value)]
         return []
 
+    def restore(self):
+        """Restore constraint state."""
+        try:
+            self._constraint_attributes = self._ca_history.pop()
+        except IndexError:
+            logger.debug("No more attribute history to restore from. restore is a NOOP")
+
+    def preserve(self):
+        """Save the current state of the constraints."""
+        ca_copy = self._constraint_attributes.copy()
+        ca_copy["found_values"] = self._constraint_attributes["found_values"].copy()
+        self._ca_history.append(ca_copy)
+
     # Make iterable to work with `Constraint`.
     # Since this is a leaf, simple return ourselves.
     def __iter__(self):
         yield self
 
     def __repr__(self):
-        result = '{}({})'.format(
-            self.__class__.__name__,
-            str(self.__dict__)
-        )
+        result = f"{self.__class__.__name__}({str(self._constraint_attributes)})"
         return result
 
     def __str__(self):
-        result = '{}({})'.format(
-            self.__class__.__name__,
-            {
-                str_attr: getattr(self, str_attr)
-                for str_attr in self._str_attrs
-            }
+        result = (
+            f"{self.__class__.__name__}("
+            f"{ ({str_attr: getattr(self, str_attr) for str_attr in self._str_attrs}) })"
         )
         return result
 
 
 class ConstraintTrue(SimpleConstraintABC):
-    """Always return True"""
+    """Always return True."""
 
     def check_and_set(self, item):
+        """
+        Empty method to return True from parent abstract method.
+
+        Returns
+        -------
+        bool
+            True from parent abstract method.
+        """
         return super(ConstraintTrue, self).check_and_set(item)
 
 
 class SimpleConstraint(SimpleConstraintABC):
-    """A basic constraint
-
-    Parameters
-    ----------
-    init : dict
-        dict where the key:value pairs define
-        the following parameters
-
-    value : object or None
-        Value that must be matched.
-        If None, any retrieved value will match.
-
-    sources : func(item) or None
-        Function taking `item` as argument used to
-        retrieve a value to check against.
-        If None, the item itself is used as the value.
-
-    force_unique : bool
-        If the constraint is satisfied, reset `value`
-        to the value of the source.
-
-    test : function
-        The test function for the constraint.
-        Takes two arguments:
-
-            - constraint
-            - object to compare against.
-
-        Returns a boolean.
-        Default is `SimpleConstraint.eq`
-
-    name : str or None
-        Option name for constraint
-
-    reprocess_on_match : bool
-        Reprocess the item if the constraint is satisfied.
-
-    reprocess_on_fail : bool
-        Reprocess the item if the constraint is not satisfied.
-
-    work_over : ListCategory.[BOTH, EXISTING, RULES]
-        The condition on which this constraint should operate.
-
-    reprocess_rules : [rule[,..]] or None
-        List of rules to be applied to.
-        If None, calling function will determine the ruleset.
-        If empty, [], all rules will be used.
-
-    Attributes
-    ----------
-    All `Parameters` are also `Attributes`
+    """
+    A basic constraint.
 
     Examples
     --------
-
     Create a constraint where the attribute `attr` of an object
     matches the value `my_value`:
 
-    >>> c = SimpleConstraint(value='my_value')
+    >>> c = SimpleConstraint(value="my_value")
     >>> print(c)
     SimpleConstraint({'name': None, 'value': 'my_value'})
 
     To check a constraint, call `check_and_set`. A successful match
     will return a tuple of `True` and a reprocess list.
-    >>> item = 'my_value'
+    >>> item = "my_value"
     >>> c.check_and_set(item)
     (True, [])
 
     If it doesn't match, `False` will be returned.
-    >>> bad_item = 'not_my_value'
+    >>> bad_item = "not_my_value"
     >>> c.check_and_set(bad_item)
     (False, [])
 
     A `SimpleConstraint` can also be initialized by a `dict`
     of the relevant parameters:
-    >>> init = {'value': 'my_value'}
+    >>> init = {"value": "my_value"}
     >>> c = SimpleConstraint(init)
     >>> print(c)
     SimpleConstraint({'name': None, 'value': 'my_value'})
@@ -259,22 +279,62 @@ class SimpleConstraint(SimpleConstraintABC):
     >>> matched, reprocess = c.check_and_set(item)
     >>> print(c)
     SimpleConstraint({'name': None, 'value': None})
-
     """
 
     def __init__(
-            self,
-            init=None,
-            sources=None,
-            force_unique=True,
-            test=None,
-            reprocess_on_match=False,
-            reprocess_on_fail=False,
-            work_over=ListCategory.BOTH,
-            reprocess_rules=None,
-            **kwargs
+        self,
+        init=None,
+        sources=None,
+        force_unique=True,
+        test=None,
+        reprocess_on_match=False,
+        reprocess_on_fail=False,
+        work_over=ListCategory.BOTH,
+        reprocess_rules=None,
+        **kwargs,
     ):
+        """
+        Initialize a new SimpleConstraint.
 
+        Parameters
+        ----------
+        init : dict
+            Dictionary where the key:value pairs define
+            the following parameters.
+
+        sources : func(item) or None
+            Function taking `item` as argument used to
+            retrieve a value to check against.
+            If None, the item itself is used as the value.
+
+        force_unique : bool
+            If the constraint is satisfied, reset `value`
+            to the value of the source.
+
+        test : function
+            The test function for the constraint.
+            Takes two arguments:
+
+                - constraint
+                - object to compare against.
+
+            Returns a boolean.
+            Default is `SimpleConstraint.eq`
+
+        reprocess_on_match : bool
+            Reprocess the item if the constraint is satisfied.
+
+        reprocess_on_fail : bool
+            Reprocess the item if the constraint is not satisfied.
+
+        work_over : ListCategory.[BOTH, EXISTING, RULES]
+            The condition on which this constraint should operate.
+
+        reprocess_rules : [rule[,..]] or None
+            List of rules to be applied to.
+            If None, calling function will determine the ruleset.
+            If empty, [], all rules will be used.
+        """
         # Defined attributes
         self.sources = sources
         self.force_unique = force_unique
@@ -292,7 +352,8 @@ class SimpleConstraint(SimpleConstraintABC):
             self.test = self.eq
 
     def check_and_set(self, item):
-        """Check and set the constraint
+        """
+        Check and set the constraint.
 
         Returns
         -------
@@ -312,97 +373,101 @@ class SimpleConstraint(SimpleConstraintABC):
         if self.matched:
             if self.force_unique:
                 self.value = source_value
+            self.found_values.add(self.value)
 
         # Determine reprocessing
         reprocess = []
-        if ((self.matched and self.reprocess_on_match) or
-                (not self.matched and self.reprocess_on_fail)):
-            reprocess.append(ProcessList(
-                items=[item],
-                work_over=self.work_over,
-                rules=self.reprocess_rules,
-                trigger_constraints=[self.id]
-            ))
+        if (self.matched and self.reprocess_on_match) or (
+            not self.matched and self.reprocess_on_fail
+        ):
+            reprocess.append(
+                ProcessList(
+                    items=[item],
+                    work_over=self.work_over,
+                    rules=self.reprocess_rules,
+                    trigger_constraints=[self.id],
+                )
+            )
 
         return self.matched, reprocess
 
     def eq(self, value1, value2):
-        """True if constraint.value and item are equal."""
+        """
+        Check if constraint.value and item are equal.
+
+        Parameters
+        ----------
+        value1 : any
+            The first value to compare.
+        value2 : any
+            The second value to compare.
+
+        Returns
+        -------
+        bool
+            True if the two values are deemed equal.
+        """
         return value1 == value2
 
 
 class AttrConstraint(SimpleConstraintABC):
-    """Test attribute of an item
-
-    Parameters
-    ----------
-    sources : [str[,...]]
-        List of attributes to query
-
-    value : str, function or None
-        The value to check for. If None and
-        `force_unique`, any value in the first
-        available source will become the value.
-        If function, the function takes no arguments
-        and returns a string.
-
-    evaluate : bool
-        Evaluate the item's value before checking condition.
-
-    force_reprocess : ListCategory.state or False
-        Add item back onto the reprocess list using
-        the specified `~jwst.associations.ProcessList` work over state.
-
-    force_unique : bool
-        If the initial value is `None` or a list of possible values,
-        the constraint will be modified to be the value first matched.
-
-    invalid_values : [str[,...]]
-        List of values that are invalid in an item.
-        Will cause a non-match.
-
-    name : str or None
-        Name of the constraint.
-
-    only_on_match : bool
-        If `force_reprocess`, only do the reprocess
-        if the entire constraint is satisfied.
-
-    onlyif : function
-        Boolean function that takes `item` as argument.
-        If True, the rest of the condition is checked. Otherwise
-        return as a matched condition
-
-    required : bool
-        One of the sources must exist. Otherwise,
-        return as a matched constraint.
+    """
+    Test attribute of an item.
 
     Attributes
     ----------
     found_values : set(str[,...])
         Set of actual found values for this condition.
-
     matched : bool
         Last result of `check_and_set`
-
     """
 
     # Attributes to show in the string representation.
-    _str_attrs = ('name', 'sources', 'value')
+    _str_attrs = ("name", "sources", "value")
 
-    def __init__(self,
-                 init=None,
-                 sources=None,
-                 evaluate=False,
-                 force_reprocess=False,
-                 force_undefined=False,
-                 force_unique=True,
-                 invalid_values=None,
-                 only_on_match=False,
-                 onlyif=None,
-                 required=True,
-                 **kwargs):
+    def __init__(
+        self,
+        init=None,
+        sources=None,
+        evaluate=False,
+        force_reprocess=False,
+        force_undefined=False,
+        force_unique=True,
+        invalid_values=None,
+        only_on_match=False,
+        onlyif=None,
+        required=True,
+        **kwargs,
+    ):
+        """
+        Initialize a new AttrConstraint.
 
+        Parameters
+        ----------
+        sources : [str[,...]]
+            List of attributes to query
+        evaluate : bool
+            Evaluate the item's value before checking condition.
+        force_reprocess : ListCategory.state or False
+            Add item back onto the reprocess list using
+            the specified `~jwst.associations.ProcessList` work over state.
+        force_unique : bool
+            If the initial value is `None` or a list of possible values,
+            the constraint will be modified to be the value first matched.
+        invalid_values : [str[,...]]
+            List of values that are invalid in an item.
+            Will cause a non-match.
+        only_on_match : bool
+            If `force_reprocess`, only do the reprocess
+            if the entire constraint is satisfied.
+        onlyif : function
+            Boolean function that takes `item` as argument.
+            If True, the rest of the condition is checked. Otherwise
+            return as a matched condition
+        required : bool
+            One of the sources must exist. Otherwise,
+            return as a matched constraint.
+        """
         # Attributes
         self.sources = sources
         self.evaluate = evaluate
@@ -413,20 +478,21 @@ class AttrConstraint(SimpleConstraintABC):
         self.only_on_match = only_on_match
         self.onlyif = onlyif
         self.required = required
-        super(AttrConstraint, self).__init__(init=init, **kwargs)
+        super().__init__(init=init, **kwargs)
 
         # Give some defaults real meaning.
         if invalid_values is None:
             self.invalid_values = []
         if onlyif is None:
-            self.onlyif = lambda item: True
+            self.onlyif = lambda _item: True
 
         # Haven't actually matched anything yet.
         self.found_values = set()
         self.matched = False
 
     def check_and_set(self, item):
-        """Check and set constraints based on item
+        """
+        Check and set constraints based on item.
 
         Parameters
         ----------
@@ -451,7 +517,7 @@ class AttrConstraint(SimpleConstraintABC):
                         items=[item],
                         work_over=self.force_reprocess,
                         only_on_match=self.only_on_match,
-                        trigger_constraints=[self.id]
+                        trigger_constraints=[self.id],
                     )
                 )
             self.matched = True
@@ -460,9 +526,7 @@ class AttrConstraint(SimpleConstraintABC):
         # Get the condition information.
         try:
             source, value = getattr_from_list(
-                item,
-                self.sources,
-                invalid_values=self.invalid_values
+                item, self.sources, invalid_values=self.invalid_values
             )
         except KeyError:
             if self.required and not self.force_undefined:
@@ -499,23 +563,20 @@ class AttrConstraint(SimpleConstraintABC):
                 match_value = self.value
             if not is_iterable(evaled):
                 evaled = [evaled]
-            matched = []
             for evaled_item in evaled:
                 value = str(evaled_item)
                 if meets_conditions(value, match_value):
-                    matched.append(evaled_item)
-
-            # If the condition is not matched, leave now.
-            if not matched:
+                    break
+            else:
+                # The condition is not matched, leave now.
                 self.matched = False
                 return self.matched, reprocess
 
-            # Matches were found. The first match becomes
-            # the value for the current constraint.
-            # The rest get reprocessed.
-            value = str(matched[0])
-            if matched[1:]:
-                reprocess.append(reprocess_multivalue(item, source, matched[1:], self))
+            # A match was found. If there is a list of potential values,
+            # set them up for reprocessing.
+            next_evaleds = [next_evaled for next_evaled in evaled if next_evaled != evaled_item]
+            if next_evaleds:
+                reprocess.append(reprocess_multivalue(item, source, next_evaleds, self))
 
         # At this point, the constraint has passed.
         # Fix the conditions.
@@ -533,7 +594,7 @@ class AttrConstraint(SimpleConstraintABC):
                     items=[item],
                     work_over=self.force_reprocess,
                     only_on_match=self.only_on_match,
-                    trigger_constraints=[self.id]
+                    trigger_constraints=[self.id],
                 )
             )
 
@@ -543,38 +604,8 @@ class AttrConstraint(SimpleConstraintABC):
 
 
 class Constraint:
-    """Constraint that is made up of SimpleConstraints
-
-    Parameters
-    ----------
-    init : object or [object[,...]]
-        A single object or list of objects where the
-        objects are as follows.
-        - SimpleConstraint or subclass
-        - Constraint
-
-    reduce : function
-        A reduction function with signature `x(iterable)`
-        where `iterable` is the `components` list. Returns
-        boolean indicating state of the components.
-        Default value is `Constraint.all`
-
-    name : str or None
-        Optional name for constraint.
-
-    reprocess_on_match : bool
-        Reprocess the item if the constraint is satisfied.
-
-    reprocess_on_fail : bool
-        Reprocess the item if the constraint is not satisfied.
-
-    work_over : ListCategory.[BOTH, EXISTING, RULES]
-        The condition on which this constraint should operate.
-
-    reprocess_rules : [rule[,..]] or None
-        List of rules to be applied to.
-        If None, calling function will determine the ruleset.
-        If empty, [], all rules will be used.
+    """
+    Constraint that is made up of SimpleConstraints.
 
     Attributes
     ----------
@@ -597,9 +628,9 @@ class Constraint:
     -----
     Named constraints can be accessed directly through indexing:
 
-    >>> c = Constraint(SimpleConstraint(name='simple', value='a_value'))
-    >>> c['simple']  # doctest: +SKIP
-    SimpleConstraint({'sources': <function SimpleConstraint.__init__.<locals>.<lambda> at 0x7f8be05f5730>,
+    >>> c = Constraint(SimpleConstraint(name="simple", value="a_value"))
+    >>> c["simple"]  # doctest: +SKIP
+    SimpleConstraint({'sources': <function SimpleConstraint.__init__.<locals>.<lambda>,
                       'force_unique': True,
                       'test': <bound method SimpleConstraint.eq of SimpleConstraint({...})>,
                       'reprocess_on_match': False,
@@ -610,16 +641,51 @@ class Constraint:
                       'name': 'simple',
                       'matched': False})
     """
+
     def __init__(
-            self,
-            init=None,
-            reduce=None,
-            name=None,
-            reprocess_on_match=False,
-            reprocess_on_fail=False,
-            work_over=ListCategory.BOTH,
-            reprocess_rules=None
+        self,
+        init=None,
+        reduce=None,
+        name=None,
+        reprocess_on_match=False,
+        reprocess_on_fail=False,
+        work_over=ListCategory.BOTH,
+        reprocess_rules=None,
     ):
+        """
+        Initialize a new Constraint.
+
+        Parameters
+        ----------
+        init : object or [object[,...]]
+            A single object or list of objects where the
+            objects are as follows.
+            - SimpleConstraint or subclass
+            - Constraint
+
+        reduce : function
+            A reduction function with signature `x(iterable)`
+            where `iterable` is the `components` list. Returns
+            boolean indicating state of the components.
+            Default value is `Constraint.all`
+
+        name : str or None
+            Optional name for constraint.
+
+        reprocess_on_match : bool
+            Reprocess the item if the constraint is satisfied.
+
+        reprocess_on_fail : bool
+            Reprocess the item if the constraint is not satisfied.
+
+        work_over : ListCategory.[BOTH, EXISTING, RULES]
+            The condition on which this constraint should operate.
+
+        reprocess_rules : [rule[,..]] or None
+            List of rules to be applied to.
+            If None, calling function will determine the ruleset.
+            If empty, [], all rules will be used.
+        """
         self.constraints = []
 
         # Initialize from named parameters
@@ -647,9 +713,9 @@ class Constraint:
             self.constraints = [init]
         else:
             raise TypeError(
-                'Invalid initialization value type {}.'
-                '\nValid types are `SimpleConstraint`, `Constraint`,'
-                '\nor subclass.'.format(type(init))
+                f"Invalid initialization value type {type(init)}."
+                "\nValid types are `SimpleConstraint`, `Constraint`,"
+                "\nor subclass."
             )
 
         # Give some defaults real meaning.
@@ -658,8 +724,9 @@ class Constraint:
             self.reduce = self.all
 
     @property
-    def dup_names(self): # -> dict[str, list[typing.Union[SimpleConstraint, Constraint]]]:
-        """Return dictionary of constraints with duplicate names
+    def dup_names(self):
+        """
+        Return dictionary of constraints with duplicate names.
 
         This method is meant to be overridden by classes
         that need to traverse a list of constraints.
@@ -670,11 +737,11 @@ class Constraint:
             Returns a mapping between the duplicated name
             and all the constraints that define that name.
         """
-        attrs = self.get_all_attr('name')
-        constraints, names = zip(*attrs)
+        attrs = self.get_all_attr("name")
+        constraints, names = zip(*attrs, strict=True)
         dups = [name for name, count in collections.Counter(names).items() if count > 1]
         result = collections.defaultdict(list)
-        for name, constraint in zip(names, constraints):
+        for name, constraint in zip(names, constraints, strict=True):
             if name in dups:
                 result[name].append(constraint)
 
@@ -684,21 +751,23 @@ class Constraint:
 
     @property
     def id(self):
-        """Return identifyer for the constraint
+        """
+        Return identifier for the constraint.
 
         Returns
         -------
         id : str
-            The identifyer
+            The identifier
         """
-        return f'{self.__class__.__name__}:{self.name}'
+        return f"{self.__class__.__name__}:{self.name}"
 
     def append(self, constraint):
-        """Append a new constraint"""
+        """Append a new constraint."""
         self.constraints.append(constraint)
 
     def check_and_set(self, item, work_over=ListCategory.BOTH):
-        """Check and set the constraint
+        """
+        Check and set the constraint.
 
         Returns
         -------
@@ -715,32 +784,47 @@ class Constraint:
         self.matched, reprocess = self.reduce(item, self.constraints)
 
         # Determine reprocessing
-        if ((self.matched and self.reprocess_on_match) or
-                (not self.matched and self.reprocess_on_fail)):
-            reprocess.append([ProcessList(
-                items=[item],
-                work_over=self.work_over,
-                rules=self.reprocess_rules,
-                trigger_constraints=[self.id]
-            )])
+        if (self.matched and self.reprocess_on_match) or (
+            not self.matched and self.reprocess_on_fail
+        ):
+            reprocess.append(
+                [
+                    ProcessList(
+                        items=[item],
+                        work_over=self.work_over,
+                        rules=self.reprocess_rules,
+                        trigger_constraints=[self.id],
+                    )
+                ]
+            )
 
         return self.matched, list(chain(*reprocess))
 
     def copy(self):
-        """Copy ourselves"""
+        """
+        Copy ourselves.
+
+        Returns
+        -------
+        object
+            Deepcopy of self.
+        """
         return deepcopy(self)
 
-    def get_all_attr(self, attribute: str): # -> list[tuple[typing.Union[SimpleConstraint, Constraint], typing.Any]]:
-        """Return the specified attribute
-
-        This method is meant to be overridden by classes
-        that need to traverse a list of constraints.
+    def get_all_attr(self, attribute, name=None):
+        """
+        Return the specified attribute for specified constraints.
 
         Parameters
         ----------
         attribute : str
             The attribute to retrieve
 
+        name : str or None
+            Only return attribute if the name of the current constraint
+            matches the requested named constraints. If None, always
+            return value.
+
         Returns
         -------
         result : [(SimpleConstraint or Constraint, object)[,...]]
@@ -753,18 +837,44 @@ class Constraint:
             If the attribute is not found.
         """
         result = []
-        value = getattr(self, attribute)
-        if value is not None:
-            result = [(self, value)]
+        if name is None or name == self.name:
+            value = getattr(self, attribute, None)
+            if value is not None:
+                result = [(self, value)]
         for constraint in self.constraints:
-            result.extend(constraint.get_all_attr(attribute))
+            result.extend(constraint.get_all_attr(attribute, name=name))
 
         return result
 
+    def preserve(self):
+        """Preserve all constraint states."""
+        for constraint in self.constraints:
+            constraint.preserve()
+
+    def restore(self):
+        """Restore all constraint states."""
+        for constraint in self.constraints:
+            constraint.restore()
+
     @staticmethod
     def all(item, constraints):
-        """Return positive only if all results are positive."""
+        """
+        Return positive only if all results are positive.
 
+        Parameters
+        ----------
+        item : ACID
+            The candidate.
+        constraints : list[Constraint, ...]
+            The list of constraints to check.
+
+        Returns
+        -------
+        bool, list(Constraint, ...) or None
+            True if all constraints positive, with empty list.
+            If no constraints, False and empty list. Otherwise
+            False with list of constraints to reprocess.
+        """
         # If there are no constraints, there is nothing to match.
         # Result is false.
         if len(constraints) == 0:
@@ -805,7 +915,23 @@ class Constraint:
 
     @staticmethod
     def any(item, constraints):
-        """Return the first successful constraint."""
+        """
+        Return the first successful constraint.
+
+        Parameters
+        ----------
+        item : ACID
+            The candidate.
+        constraints : list[Constraint, ...]
+            The list of constraints to check.
+
+        Returns
+        -------
+        bool, list(Constraint, ...) or None
+            False, [] if no match or constraints to reprocess.
+            True, list(Constraints) if match found, and any constraints
+            to reprocess listed.
+        """
         # If there are no constraints, there is nothing to match.
         # Result is false.
         if len(constraints) == 0:
@@ -822,30 +948,69 @@ class Constraint:
 
     @staticmethod
     def notany(item, constraints):
-        """True if none of the constraints match"""
+        """
+        Check if none of the constraints match; true if none do.
+
+        Parameters
+        ----------
+        item : ACID
+            The candidate.
+        constraints : list[Constraint, ...]
+            The list of constraints to check.
+
+        Returns
+        -------
+        bool
+            True if none of the constraints match.
+        """
         match, to_reprocess = Constraint.any(item, constraints)
         return not match, to_reprocess
 
     @staticmethod
     def notall(item, constraints):
-        """True if not all of the constraints match"""
+        """
+        Check if not all of the constraints match; true if not all do.
+
+        Parameters
+        ----------
+        item : ACID
+            The candidate.
+        constraints : list[Constraint, ...]
+            The list of constraints to check.
+
+        Returns
+        -------
+        bool
+            True if not all constraints match.
+        """
         match, to_reprocess = Constraint.all(item, constraints)
         return not match, to_reprocess
 
     def __delitem__(self, key):
-        """Not implemented"""
-        raise NotImplementedError('Cannot delete a constraint by index.')
+        """Not implemented."""
+        raise NotImplementedError("Cannot delete a constraint by index.")
 
     # Make iterable
     def __iter__(self):
-        for constraint in chain(*map(iter, self.constraints)):
-            yield constraint
+        yield from chain(*map(iter, self.constraints))
 
     # Index implementation
     def __getitem__(self, key):
-        """Retrieve a named constraint"""
+        """
+        Retrieve a named constraint.
+
+        Parameters
+        ----------
+        key : str
+            The key to retrieve a value with.
+
+        Returns
+        -------
+        jwst.associations.lib.constraint.Constraint
+            The constraint to be retrieved.
+        """
         for constraint in self.constraints:
-            name = getattr(constraint, 'name', None)
+            name = getattr(constraint, "name", None)
             if name is not None and name == key:
                 return constraint
             try:
@@ -854,60 +1019,47 @@ class Constraint:
                 pass
             else:
                 return found
-        raise KeyError('Constraint {} not found'.format(key))
+        raise KeyError(f"Constraint {key} not found")
 
     def __repr__(self):
-        result = '{}(name={}).{}([{}])'.format(
+        result = "{}(name={}).{}([{}])".format(
             self.__class__.__name__,
-            str(getattr(self, 'name', None)),
+            str(getattr(self, "name", None)),
             str(self.reduce.__name__),
-            ''.join([
-                repr(constraint)
-                for constraint in self.constraints
-            ])
+            "".join([repr(constraint) for constraint in self.constraints]),
         )
         return result
 
     def __setitem__(self, key, value):
-        """Not implemented"""
-        raise NotImplementedError('Cannot set constraints by index.')
+        """Not implemented."""
+        raise NotImplementedError("Cannot set constraints by index.")
 
     def __str__(self):
-        result = '\n'.join([
-            str(constraint)
-            for constraint in self
-            if constraint.name is not None
-        ])
+        result = "\n".join([str(constraint) for constraint in self if constraint.name is not None])
         return result
 
 
-# ---------
 # Utilities
-# ---------
 def meets_conditions(value, conditions):
-    """Check whether value meets any of the provided conditions
+    """
+    Check whether value meets any of the provided conditions.
 
     Parameters
     ----------
-    values : str
+    value : str
         The value to be check with.
-
-    condition : regex,
+    conditions : regex,
         Regular expressions to match against.
 
     Returns
     -------
-    True if any condition is meant.
+    bool
+        True if any condition is meant.
     """
-
     if not is_iterable(conditions):
         conditions = [conditions]
     for condition in conditions:
-        condition = ''.join([
-            '^',
-            condition,
-            '$'
-        ])
+        condition = "".join(["^", condition, "$"])
         match = re.match(condition, value, flags=re.IGNORECASE)
         if match:
             return True
@@ -915,19 +1067,17 @@ def meets_conditions(value, conditions):
 
 
 def reprocess_multivalue(item, source, values, constraint):
-    """Reprocess items that have a list of values
+    """
+    Complete reprocessing of items that have a list of values.
 
     Parameters
     ----------
     item : dict
         The item.
-
     source : str
         The attribute which has the multi-values.
-
     values : list
         The list of values
-
     constraint : Constraint
         The constraint which is triggering the reprocessing.
 
@@ -941,5 +1091,5 @@ def reprocess_multivalue(item, source, values, constraint):
         new_item = PoolRow(item)
         new_item[source] = str(value)
         reprocess_items.append(new_item)
-    process_list = (ProcessList(items=reprocess_items, trigger_constraints=[constraint.id]))
+    process_list = ProcessList(items=reprocess_items, trigger_constraints=[constraint.id])
     return process_list
