@@ -1,7 +1,4 @@
-"""Association Rules: Basic
-"""
-import os
-import sys
+"""Basic association rules."""  # noqa: INP001
 
 from jwst.associations import Association
 from jwst.associations.registry import RegistryMarker
@@ -9,28 +6,29 @@ from jwst.associations.lib.constraint import ConstraintTrue
 
 
 @RegistryMarker.rule
-class Rule_1(Association):
-    """Basic rule"""
+class Rule1(Association):
+    """Basic rule for testing."""
 
     def __init__(self, version_id=None):
         self.constraints = ConstraintTrue()
-        super(Rule_1, self).__init__(version_id=version_id)
-        self.data['members'] = []
+        super(Rule1, self).__init__(version_id=version_id)
+        self.data["members"] = []
 
     def _add(self, item):
-        self.data['members'].append(item)
+        self.data["members"].append(item)
 
     def is_item_member(self, item):
-        """Check if item is already a member of this association
+        """
+        Check if item is already a member of this association.
 
         Parameters
         ----------
-        item: dict
+        item : dict
             The item to add.
 
         Returns
         -------
-        is_item_member: bool
+        is_item_member : bool
             True if item is a member.
         """
-        return item in self.data['members']
+        return item in self.data["members"]
