@@ -1,29 +1,23 @@
 """test_associations: Test of general Association functionality."""
+
 import pytest
+from astropy.utils.data import get_pkg_data_filename
 
 from jwst.associations.tests import helpers
-
-from jwst.associations import (
-    Association,
-    AssociationError,
-    AssociationRegistry,
-    generate)
-from jwst.associations.registry import (
-    import_from_file,
-)
+from jwst.associations import Association, AssociationError, AssociationRegistry, generate
 from jwst.associations.lib.dms_base import DMSAttrConstraint
 
 
 # Basic Association object
 def test_read_assoc_defs():
     rules = AssociationRegistry(
-        [helpers.t_path('data/asn_rules_set1.py')],
-        include_default=False
+        [get_pkg_data_filename("data/asn_rules_set1.py", package="jwst.associations.tests")],
+        include_default=False,
     )
     assert len(rules) >= 2
     rule_names = helpers.get_rule_names(rules)
-    assert 'DMS_Level3_Base_Set1' not in rules
-    valid_rules = ['Asn_Dither_Set1', 'Asn_WFS_Set1']
+    assert "DMSLevel3BaseSet1" not in rules
+    valid_rules = ["AsnDitherSet1", "AsnWFSSet1"]
     for rule in valid_rules:
         assert rule in rule_names
 
@@ -32,8 +26,8 @@ def test_read_assoc_defs_fromdefault():
     rules = AssociationRegistry()
     assert len(rules) >= 3
     rule_names = helpers.get_rule_names(rules)
-    assert 'DMS_Level3_Base' not in rules
-    valid_rules = ['Asn_Lv3Image', 'Asn_Lv3WFSCMB']
+    assert "DMS_Level3_Base" not in rules
+    valid_rules = ["Asn_Lv3Image", "Asn_Lv3WFSCMB"]
     for rule in valid_rules:
         assert rule in rule_names
 
@@ -46,25 +40,20 @@ def test_registry_backref():
 
 def test_nodefs():
     with pytest.raises(AssociationError):
-        rules = AssociationRegistry(include_default=False)
+        AssociationRegistry(include_default=False)
 
 
 def test_multi_rules():
     rule_files = [
-        helpers.t_path('data/asn_rules_set1.py'),
-        helpers.t_path('data/asn_rules_set2.py')
+        get_pkg_data_filename("data/asn_rules_set1.py", package="jwst.associations.tests"),
+        get_pkg_data_filename("data/asn_rules_set2.py", package="jwst.associations.tests"),
     ]
     rules = AssociationRegistry(rule_files, include_default=False)
     assert len(rules) == 4
     rule_names = helpers.get_rule_names(rules)
-    assert 'DMS_Level3_Base_Set1' not in rule_names
-    assert 'DMS_Level3_Base_Set2' not in rule_names
-    valid_rules = [
-        'Asn_Dither_Set1',
-        'Asn_Dither_Set2',
-        'Asn_WFS_Set1',
-        'Asn_WFS_Set2'
-    ]
+    assert "DMSLevel3BaseSet1" not in rule_names
+    assert "DMSLevel3BaseSet2" not in rule_names
+    valid_rules = ["AsnDitherSet1", "AsnDitherSet2", "AsnWFSSet1", "AsnWFSSet2"]
 
     for rule in valid_rules:
         assert rule in rule_names
@@ -76,57 +65,57 @@ def test_base_instantiation():
 
 
 @pytest.mark.parametrize(
-    'constraints, pool, n_asns',
+    "constraints, pool, n_asns",
     [
         (
             DMSAttrConstraint(
-                name='obs_id',
-                value='V99009001001P0000000002101',
-                sources=['obs_id']
+                name="obs_id", value="V99009001001P0000000002101", sources=["obs_id"]
+            ),
+            get_pkg_data_filename(
+                "data/pool_018_all_exptypes.csv", package="jwst.associations.tests"
             ),
-            helpers.t_path('data/pool_018_all_exptypes.csv'),
             1,
         ),
         (
-            DMSAttrConstraint(
-                name='obs_id',
-                value='junk',
-                sources=['obs_id']
+            DMSAttrConstraint(name="obs_id", value="junk", sources=["obs_id"]),
+            get_pkg_data_filename(
+                "data/pool_001_candidates.csv", package="jwst.associations.tests"
             ),
-            helpers.t_path('data/pool_001_candidates.csv'),
             0,
         ),
         (
             DMSAttrConstraint(
-                name='asn_candidate_id',
-                value='.+(o001|o002).+',
-                sources=['asn_candidate'],
+                name="asn_candidate_id",
+                value=".+(o001|o002).+",
+                sources=["asn_candidate"],
                 force_unique=False,
                 is_acid=True,
                 evaluate=True,
             ),
-            helpers.t_path('data/pool_001_candidates.csv'),
+            get_pkg_data_filename(
+                "data/pool_001_candidates.csv", package="jwst.associations.tests"
+            ),
             22,
         ),
         (
             DMSAttrConstraint(
-                name='asn_candidate_id',
-                value='.+(o001|o002).+',
-                sources=['asn_candidate'],
+                name="asn_candidate_id",
+                value=".+(o001|o002).+",
+                sources=["asn_candidate"],
                 force_unique=True,
                 is_acid=True,
                 evaluate=True,
             ),
-            helpers.t_path('data/pool_001_candidates.csv'),
+            get_pkg_data_filename(
+                "data/pool_001_candidates.csv", package="jwst.associations.tests"
+            ),
             24,
         ),
-    ]
+    ],
 )
 def test_global_constraints(constraints, pool, n_asns):
     """Test that global constraints get applied to all rules"""
-    rules = AssociationRegistry(
-        global_constraints=constraints
-    )
+    rules = AssociationRegistry(global_constraints=constraints)
     assert len(rules) >= 3
     for constraint in constraints:
         for rule in rules:
