@@ -1,15 +1,18 @@
 """Test ProcessList, ProcessQueue, ProcessQueueSorted"""
 
-from jwst.associations.tests.helpers import (
-    combine_pools,
-    t_path
-)
+from jwst.associations.tests.helpers import combine_pools, t_path
 
-from jwst.associations.lib.process_list import *
+from jwst.associations.lib.process_list import (
+    ProcessItem,
+    ProcessList,
+    ProcessQueue,
+    ProcessQueueSorted,
+    ListCategory,
+)
 
 
 def test_item():
-    pool = combine_pools(t_path('data/pool_013_coron_nircam.csv'))
+    pool = combine_pools(t_path("data/pool_013_coron_nircam.csv"))
     item1 = ProcessItem(pool[0])
     item2 = ProcessItem(pool[1])
     assert item1 == item1
@@ -19,7 +22,7 @@ def test_item():
 
 
 def test_item_iterable():
-    pool = combine_pools(t_path('data/pool_013_coron_nircam.csv'))
+    pool = combine_pools(t_path("data/pool_013_coron_nircam.csv"))
     process_items = ProcessItem.to_process_items(pool)
     for process_item in process_items:
         assert isinstance(process_item, ProcessItem)
@@ -31,7 +34,7 @@ def test_process_queue():
         [1],
         [2, 3, 4],
         # [3, 4],  # Neither should get added but not implemented
-        [5]
+        [5],
     ]
     standard = [1, 2, 3, 4, 5]
 
@@ -43,7 +46,7 @@ def test_process_queue():
         idx += 1
         try:
             to_add = items_to_add[idx]
-        except:
+        except IndexError:
             pass
         else:
             queue.extend(to_add)
@@ -55,18 +58,18 @@ def test_process_queue_sorted():
     """Test the sorted process queue"""
     items_to_add = [
         [
-            ProcessList([1], ['r1'], work_over=ListCategory.RULES),
-            ProcessList([2], ['r2'], work_over=ListCategory.BOTH),
-            ProcessList([3], ['r3'], work_over=ListCategory.EXISTING),
+            ProcessList([1], ["r1"], work_over=ListCategory.RULES),
+            ProcessList([2], ["r2"], work_over=ListCategory.BOTH),
+            ProcessList([3], ["r3"], work_over=ListCategory.EXISTING),
         ],
         [
-            ProcessList([4], ['r4'], work_over=ListCategory.EXISTING),
+            ProcessList([4], ["r4"], work_over=ListCategory.EXISTING),
         ],
         [
-            ProcessList([5], ['r5'], work_over=ListCategory.BOTH),
+            ProcessList([5], ["r5"], work_over=ListCategory.BOTH),
         ],
         [
-            ProcessList([6], ['r6'], work_over=ListCategory.RULES),
+            ProcessList([6], ["r6"], work_over=ListCategory.RULES),
         ],
     ]
 
@@ -84,7 +87,7 @@ def test_process_queue_sorted():
         idx += 1
         try:
             to_add = items_to_add[idx]
-        except:
+        except IndexError:
             pass
         else:
             queue.extend(to_add)
@@ -96,18 +99,18 @@ def test_process_queue_dups():
     """Test the sorted process queue with same rulesets."""
     items_to_add = [
         [
-            ProcessList([1], ['r1'], work_over=ListCategory.RULES),
-            ProcessList([2], ['r1'], work_over=ListCategory.BOTH),
-            ProcessList([3], ['r1'], work_over=ListCategory.EXISTING),
+            ProcessList([1], ["r1"], work_over=ListCategory.RULES),
+            ProcessList([2], ["r1"], work_over=ListCategory.BOTH),
+            ProcessList([3], ["r1"], work_over=ListCategory.EXISTING),
         ],
         [
-            ProcessList([4], ['r1'], work_over=ListCategory.EXISTING),
+            ProcessList([4], ["r1"], work_over=ListCategory.EXISTING),
         ],
         [
-            ProcessList([5], ['r1'], work_over=ListCategory.BOTH),
+            ProcessList([5], ["r1"], work_over=ListCategory.BOTH),
         ],
         [
-            ProcessList([6], ['r1'], work_over=ListCategory.RULES),
+            ProcessList([6], ["r1"], work_over=ListCategory.RULES),
         ],
     ]
 
@@ -125,7 +128,7 @@ def test_process_queue_dups():
         idx += 1
         try:
             to_add = items_to_add[idx]
-        except:
+        except IndexError:
             pass
         else:
             queue.extend(to_add)
