@@ -1,31 +1,28 @@
 import numpy as np
 
 import logging
+
 log = logging.getLogger(__name__)
 log.setLevel(logging.DEBUG)
 
 
 def subtract(model1, model2):
     """
-    Short Summary
-    -------------
-    Subtract one data model from another, and include updated DQ
-    in output.
+    Subtract one data model from another, and include updated DQ in output.
 
     Parameters
     ----------
-    model1: JWST data model
-        input data model on which subtraction will be performed
+    model1 : ImageModel or IFUImageModel
+        Input data model on which subtraction will be performed
 
-    model2: JWST data model
-        input data model that will be subtracted from the first model
+    model2 : ImageModel or IFUImageModel
+        Input data model that will be subtracted from the first model
 
     Returns
     -------
-    output: JWST data model
-        subtracted data model
+    output : ImageModel or IFUImageModel
+        Subtracted data model
     """
-
     # Create the output model as a copy of the first input
     output = model1.copy()
 
