@@ -1,6 +1,8 @@
+"""Coronagraphic calibration steps and tools."""
+
 from .stack_refs_step import StackRefsStep
 from .align_refs_step import AlignRefsStep
 from .klip_step import KlipStep
 from .hlsp_step import HlspStep
 
-__all__ = ['StackRefsStep', 'AlignRefsStep', 'KlipStep', 'HlspStep']
+__all__ = ["StackRefsStep", "AlignRefsStep", "KlipStep", "HlspStep"]
