@@ -1,46 +1,55 @@
-""" Replace bad pixels and align psf image with target image."""
+"""Replace bad pixels and align psf image with target image."""
 
-from stcal.dqflags import interpret_bit_flags
+from astropy.nddata.bitmask import interpret_bit_flags
+from stdatamodels.jwst import datamodels
+from stdatamodels.jwst.datamodels.dqflags import pixel
 
-from jwst.datamodels.dqflags import pixel
-
-from ..stpipe import Step
-from .. import datamodels
+from jwst.stpipe import Step
 from . import imageregistration
-from . median_replace_img import median_replace_img
+from .median_replace_img import median_replace_img
 
 __all__ = ["AlignRefsStep"]
 
 
 class AlignRefsStep(Step):
-
-    """
-    AlignRefsStep: Align coronagraphic PSF images
-    with science target images.
-    """
+    """Align coronagraphic PSF images with science target images."""
 
     class_alias = "align_refs"
 
     spec = """
         median_box_length = integer(default=3,min=0) # box size for the median filter
         bad_bits = string(default="DO_NOT_USE") # the DQ bit values of bad pixels
-    """
+    """  # noqa: E501
 
-    reference_file_types = ['psfmask']
+    reference_file_types = ["psfmask"]
 
     def process(self, target, psf):
+        """
+        Execute the AlignRefs calibration step.
 
+        Parameters
+        ----------
+        target : str or CubeModel
+            CubeModel or file containing science target data
+        psf : str or CubeModel
+            CubeModel or file containing PSF image stack
+
+        Returns
+        -------
+        result : CubeModel
+            CubeModel containing stack of PSF reference images shifted to the
+            first science target image
+        """
         # Open the input science target model
         with datamodels.open(target) as target_model:
-
             # Get the name of the psf mask reference file to use
-            self.mask_name = self.get_reference_file(target_model, 'psfmask')
-            self.log.info('Using PSFMASK reference file %s', self.mask_name)
+            self.mask_name = self.get_reference_file(target_model, "psfmask")
+            self.log.info("Using PSFMASK reference file %s", self.mask_name)
 
             # Check for a valid reference file
-            if self.mask_name == 'N/A':
-                self.log.warning('No PSFMASK reference file found')
-                self.log.warning('Align_refs step will be skipped')
+            if self.mask_name == "N/A":
+                self.log.warning("No PSFMASK reference file found")
+                self.log.warning("Align_refs step will be skipped")
                 return None
 
             # Open the psf mask reference file
@@ -54,7 +63,7 @@ class AlignRefsStep(Step):
 
             # Get the bit value of bad pixels. A value of 0 treats all pixels as good.
             bad_bitvalue = self.bad_bits
-            bad_bitvalue = interpret_bit_flags(bad_bitvalue, mnemonic_map=pixel)
+            bad_bitvalue = interpret_bit_flags(bad_bitvalue, flag_name_map=pixel)
             if bad_bitvalue is None:
                 bad_bitvalue = 0
 
@@ -65,9 +74,8 @@ class AlignRefsStep(Step):
             target_model = median_replace_img(target_model, box_size, bad_bitvalue)
 
             # Call the alignment routine
-            result = imageregistration.align_models(target_model, psf_model,
-                                                    mask_model)
-            result.meta.cal_step.align_psfs = 'COMPLETE'
+            result = imageregistration.align_models(target_model, psf_model, mask_model)
+            result.meta.cal_step.align_psfs = "COMPLETE"
 
             mask_model.close()
             psf_model.close()
