@@ -1,11 +1,14 @@
 /*
-The detector pixels are represented by a 'point cloud' on the sky. The IFU cube is
-represented by a 3-D regular grid. This module finds the point cloud members contained
-in a region centered on the center of the cube spaxel. The size of the spaxel is spatial
+If the weighting method for IFU cube building is set to 'msm' or 'emsm' this c method
+is used. 
+The detector pixels are represented by a 'point cloud' on the sky. Each point cloud member
+contains the coordinates for the pixel center, the flux, error and variance of that pixel.
+The IFU cube is represented by a 3-D regular grid. This module finds the point cloud members contained
+in a region centered on the center of the cube spaxel. The size of the spaxel in spatial
 coordinates is cdetl1 and cdelt2, while the wavelength size is zcdelt3.
-This module uses the modified shephard weighting method (emsm if weight_type =0 or msm if weight_type =1)
+This module uses the modified Shepard weighting method (emsm if weight_type =0 or msm if weight_type =1)
 to determine how to  weight each point cloud member in the spaxel.
- 
+
 Main function for Python: cube_wrapper
 
 Python signature: result = cube_wrapper(instrument, flag_dq_plane, weight_type, start_region, end_region,
@@ -17,8 +20,8 @@ Python signature: result = cube_wrapper(instrument, flag_dq_plane, weight_type,
                                         roiw_ave, cdelt1, cdelt2)
 provide more details
 
-The output of this function is a tuple of 5 arrays:(spaxel_flux, spaxel_weight, spaxel_var, spaxel_iflux, spaxel_dq) 
-example output 
+The output of this function is a tuple of 5 arrays:(spaxel_flux, spaxel_weight, spaxel_var, spaxel_iflux, spaxel_dq)
+example output
 
 Parameters
 ----------
@@ -31,39 +34,39 @@ weight_type : int
    0: use emsm weighting
    1: use msm weighting
 start_region : int
-    starting slice number for detector region used in dq flagging
-end_region: int 
-    ending slice number for detector region used in dq flagging
+    Starting slice number for detector region used in dq flagging
+end_region: int
+    Ending slice number for detector region used in dq flagging
 overlap_partial : int
-    a dq flag indicating that only a portion of the spaxel is overlapped by a mapped detector pixel
+    A dq flag indicating that only a portion of the spaxel is overlapped by a mapped detector pixel
 overlap_full : int
-    a dq flag indicating that the entire spaxel is overlapped by the mapped detector pixel
+    A dq flag indicating that the entire spaxel is overlapped by the mapped detector pixel
 xcoord : double array
-   size of naxis1. This array holds the center x axis values of the ifu cube 
+  This array holds the center x axis values of the ifu cube. It has a size of naxis1.
 ycoord : double array
-   size of naxis2. This array holds the center y axis values of the ifu cube 
+   This array holds the center y axis values of the ifu cube. It has a size of naxis2.
 zcoord : double array
-   size of naxis3. This array holds the center x axis values of the ifu cube 
+   This array holds the center x axis values of the ifu cube. It has a size of naxis3.
 flux : double array
-   size: point cloud elements. Flux of each point cloud member
+   Flux of each point cloud member.
 err : double array
-   size: point cloud elements. err of each point cloud member
+   Error of each point cloud member
 slice_no: int
-   slice number of point cloud member to be in dq flagging
+   Slice number of point cloud member to be in dq flagging
 coord1 : double array
-   size: point cloud elements. Naxis 1 coordinate of point cloud member (xi) 
+   Naxis 1 coordinate of point cloud member (xi).
 coord2 : double array
-   size: point cloud elements. Naxis 2 coordinate of point cloud member (eta)
+   Naxis 2 coordinate of point cloud member (eta).
 wave : double array
-   size: point cloud elements. Wavelength of each point cloud member
+   Wavelength of each point cloud member.
 rois_pixel : double array
-   size: point cloud elements. Roi in spatial dimension to use for point cloud member
+   Roi in spatial dimension to use for point cloud member.
 roiw_pixel : double array
-   size: point cloud elements. Roi in wavelength dimension to use point cloud member
+   Roi in wavelength dimension to use point cloud member.
 scalerad_pixel : double array
-   size: point cloud elements. MSM weight parameter to use for point cloud member
+   MSM weight parameter to use for point cloud member
 zcdelt3: double array
-   size: point cloud elements. Spectral scale to use at wavelength of point cloud member
+   Spectral scale to use at wavelength of point cloud member
 roiw_ave : double
    Average roiw for all the wavelength planes. Used in dq flagging
 cdelt1 : double
@@ -72,17 +75,17 @@ cdelt2 : double
    Naxis 2 scale for cube
 
 
-Returns
--------
-spaxel_flux : numpy.ndarray
+Sets
+----
+spaxel_flux : ndarray
   IFU spaxel cflux
-spaxel_weight : numpy.ndarray
-  IFU spaxel weight 
-spaxel_iflux : numpy.ndarray
-  IFU spaxel weight map (number of overlaps) 
-spaxel_var : numpy.ndarray
+spaxel_weight : ndarray
+  IFU spaxel weight
+spaxel_iflux : ndarray
+  IFU spaxel weight map (number of overlaps)
+spaxel_var : ndarray
   IFU spaxel error
-spaxel_dq : numpy.ndarray
+spaxel_dq : ndarray
   IFU spaxel dq
 */
 
@@ -108,7 +111,7 @@ extern int dq_miri(int start_region, int end_region, int overlap_partial, int ov
 		   double *xc, double *yc, double *zc,
 		   double *coord1, double *coord2, double *wave,
 		   double *sliceno,
-		   long ncube, int npt, 
+		   long ncube, long npt,
 		   int **spaxel_dq);
 
 extern int dq_nirspec(int overlap_partial,
@@ -117,15 +120,17 @@ extern int dq_nirspec(int overlap_partial,
 		      double *xc, double *yc, double *zc,
 		      double *coord1, double *coord2, double *wave,
 		      double *sliceno,
-		      long ncube, int npt,
+		      long ncube, long npt,
 		      int **spaxel_dq);
 
 extern int set_dqplane_to_zero(int ncube, int **spaxel_dq);
 
 // Match point cloud to sky and determine the weighting to assign to each point cloud  member
-// to matched spaxel based on ROI - weighting type - emsm
+// to matched spaxel based on ROI - weighting type is emsm.
 
-// return values: spaxel_flux, spaxel_weight, spaxel_var, spaxel_iflux
+// sets values: spaxel_flux, spaxel_weight, spaxel_var, spaxel_iflux
+
+// returns : 0 success, 1 failure
 
 int match_point_emsm(double *xc, double *yc, double *zc,
 		     double *coord1, double *coord2, double *wave,
@@ -138,21 +143,20 @@ int match_point_emsm(double *xc, double *yc, double *zc,
 		     double **spaxel_iflux) {
 
 
-  double *fluxv, *weightv, *varv, *ifluxv;  // vector for spaxel
+  double *fluxv=NULL, *weightv=NULL, *varv=NULL, *ifluxv=NULL;  // vector for spaxel
 
   int k, iwstart, iwend, ixstart,  ixend, iystart, iyend;
   int ii, nxy, ix, iy, iw, index_xy, index_cube;
   int done_search_w, done_search_y, done_search_x;
   double wdiff, ydiff, xdiff, ydist, xdist, radius;
   double d1, d2, dxy, d3, d32, w, wn, ww, weighted_flux, weighted_var;
-  
-  // allocate memory to hold output 
+
+  // allocate memory to hold output
   if (alloc_flux_arrays(ncube, &fluxv, &weightv, &varv, &ifluxv)) return 1;
-  
-    
+
+
     // loop over each point cloud member and find which roi spaxels it is found
 
-  // printf(" number detector elements %i \n" , npt);
   for (k = 0; k < npt; k++) {
     // Search wave and find match
     iwstart = -1;
@@ -184,6 +188,7 @@ int match_point_emsm(double *xc, double *yc, double *zc,
     ixend = -1;
     ii = 0;
     done_search_x = 0;
+
     while (ii < nx && done_search_x == 0) {
       xdiff = fabs(xc[ii] - coord1[k]);
       if(xdiff <= rois_pixel[k]){
@@ -198,12 +203,13 @@ int match_point_emsm(double *xc, double *yc, double *zc,
       }
       ii = ii + 1;
     }
+
     // catch the case of ixstart near nx and becomes = nx before ixend can be set.
     if(ixstart !=-1 && ixend == -1){
       ixend = nx;
       done_search_x = 1;
     }
-  
+
     // Search ycenters and find match
     iystart = -1;
     iyend = -1;
@@ -234,12 +240,14 @@ int match_point_emsm(double *xc, double *yc, double *zc,
     if(done_search_x == 1 && done_search_y ==1 && done_search_w ==1){
       // The search above for x,y  was a crude search - now narrow the search using the distance between
       // the spaxel center and point cloud
+
       for (ix = ixstart; ix< ixend; ix ++){
+
 	for ( iy = iystart; iy < iyend; iy ++){
 	  ydist = fabs(yc[iy] - coord2[k]);
 	  xdist = fabs(xc[ix] - coord1[k]);
 	  radius = sqrt( xdist*xdist + ydist*ydist);
-	  
+
 	  if (radius <= rois_pixel[k]){
 	    // Find the index for this in spatial plane
 	    index_xy = iy* nx + ix;
@@ -254,7 +262,7 @@ int match_point_emsm(double *xc, double *yc, double *zc,
 	      w = d32  +  dxy;
 	      wn = -w/(scalerad_pixel[k]/cdelt1);
 	      ww = exp(wn);
-	      
+
 	      weighted_flux =  flux[k]* ww;
 	      weighted_var = (err[k]* ww) * (err[k]*ww);
 	      fluxv[index_cube] = fluxv[index_cube] + weighted_flux;
@@ -265,10 +273,8 @@ int match_point_emsm(double *xc, double *yc, double *zc,
 	  }
 	} // end loop over iy
       } // end loop over ix
-
     } // end done_search_x, done_search_y, done_search_w
   } // end loop over point cloud
-    
 
   // assign output values:
   *spaxel_flux = fluxv;
@@ -282,8 +288,9 @@ int match_point_emsm(double *xc, double *yc, double *zc,
 
 
 // Match point cloud to sky and determine the weighting to assign to each point cloud  member
-// to matched spaxel based on ROI - weighting type - msm
-//return values: spaxel_flux, spaxel_weight, spaxel_var, spaxel_iflux
+// to matched spaxel based on ROI - weighting type = msm.
+// set values: spaxel_flux, spaxel_weight, spaxel_var, spaxel_iflux.
+// returns: 0 = success, 1 = failure. 
 
 int match_point_msm(double *xc, double *yc, double *zc,
 		    double *coord1, double *coord2, double *wave,
@@ -297,19 +304,19 @@ int match_point_msm(double *xc, double *yc, double *zc,
 		    double **spaxel_iflux) {
 
 
-  double *fluxv, *weightv, *varv, *ifluxv;  // vector for spaxel
+  double *fluxv=NULL, *weightv=NULL, *varv=NULL, *ifluxv=NULL;  // vector for spaxel
 
   int k;
   int iwstart, iwend, ixstart, ixend, iystart, iyend;
   int ii, nxy, iw, ix, iy, index_xy, index_cube;
-  int done_search_w, done_search_x, done_search_y; 
+  int done_search_w, done_search_x, done_search_y;
   double wdiff, xdiff, ydiff, radius, ydist, xdist;
   double d1, d2, dxy, d3, d32, w, wn, ww;
   double weighted_flux, weighted_var;
-  
+
   // allocate memory to hold output
   if (alloc_flux_arrays(ncube, &fluxv, &weightv, &varv, &ifluxv)) return 1;
-        
+
   // loop over each point cloud member and find which roi spaxels it is found
 
   for ( k = 0; k < npt; k++) {
@@ -363,7 +370,7 @@ int match_point_msm(double *xc, double *yc, double *zc,
 	ixend = nx;
 	done_search_x = 1;
       }
-      
+
        // Search ycenters and find match
       iystart = -1;
       iyend = -1;
@@ -417,7 +424,7 @@ int match_point_msm(double *xc, double *yc, double *zc,
 		if( wn < softrad_pixel[k]){
 		  wn = softrad_pixel[k];
 		}
-		
+
 		ww = 1.0/wn;
 		weighted_flux =  flux[k]* ww;
 		weighted_var = (err[k]* ww) * (err[k]*ww);
@@ -433,7 +440,7 @@ int match_point_msm(double *xc, double *yc, double *zc,
 
       } // end done_search_x, done_search_y, done_search_w
     } // end loop over point cloud
-    
+
 
     // assign output values:
 
@@ -461,11 +468,11 @@ PyArrayObject * ensure_array(PyObject *obj, int *is_copy) {
     }
 }
 
-
+// Wrapper code that is called from python code and sets up interface with C code.
 static PyObject *cube_wrapper(PyObject *module, PyObject *args) {
-  PyObject *result = NULL, *xco, *yco, *zco, *fluxo, *erro, *coord1o, *coord2o, *waveo, *slicenoo;
+  PyObject *result = NULL, *xco, *yco, *zco, *fluxo, *erro, *coord1o, *coord2o, *waveo, *slicenoo; // codespell:ignore erro
   PyObject *rois_pixelo, *roiw_pixelo, *scalerad_pixelo, *zcdelt3o, *softrad_pixelo, *weight_pixelo;
-  
+
   double cdelt1, cdelt2, roiw_ave;
   int  nwave, npt, nxx, nyy, ncube;
 
@@ -477,18 +484,18 @@ static PyObject *cube_wrapper(PyObject *module, PyObject *args) {
   int free_xc=0, free_yc=0, free_zc=0, free_coord1=0, free_coord2 =0 , free_wave=0, status=0;
   int free_rois_pixel=0, free_roiw_pixel=0, free_scalerad_pixel=0, free_flux=0, free_err=0, free_zcdelt3=0;
   int free_sliceno=0, free_softrad_pixel, free_weight_pixel=0;
-  
+
   PyArrayObject *xc, *yc, *zc, *flux, *err, *coord1, *coord2, *wave, *rois_pixel, *roiw_pixel, *scalerad_pixel;
   PyArrayObject *zcdelt3, *sliceno, *softrad_pixel, *weight_pixel;
   PyArrayObject *spaxel_flux_arr=NULL, *spaxel_weight_arr=NULL, *spaxel_var_arr=NULL;
-  PyArrayObject *spaxel_iflux_arr=NULL, *spaxel_dq_arr=NULL; 
+  PyArrayObject *spaxel_iflux_arr=NULL, *spaxel_dq_arr=NULL;
   npy_intp npy_ncube = 0;
 
   int  ny,nz;
 
   if (!PyArg_ParseTuple(args, "iiiiiiiOOOOOOOOOOOOOOOddd:cube_wrapper",
 			&instrument, &flag_dq_plane, &weight_type,  &start_region, &end_region, &overlap_partial, &overlap_full,
-			&xco, &yco, &zco, &coord1o, &coord2o, &waveo,  &fluxo, &erro, &slicenoo,
+			&xco, &yco, &zco, &coord1o, &coord2o, &waveo,  &fluxo, &erro, &slicenoo, // codespell:ignore erro
 			&rois_pixelo, &roiw_pixelo, &scalerad_pixelo, &weight_pixelo, &softrad_pixelo, &zcdelt3o, &roiw_ave,
 			&cdelt1, &cdelt2)) {
     return NULL;
@@ -512,7 +519,7 @@ static PyObject *cube_wrapper(PyObject *module, PyObject *args) {
       (!(coord2 = ensure_array(coord2o, &free_coord2))) ||
       (!(wave = ensure_array(waveo, &free_wave))) ||
       (!(flux = ensure_array(fluxo, &free_flux))) ||
-      (!(err = ensure_array(erro, &free_err))) ||
+      (!(err = ensure_array(erro, &free_err))) || // codespell:ignore erro
       (!(sliceno = ensure_array(slicenoo, &free_sliceno))) ||
       (!(rois_pixel = ensure_array(rois_pixelo, &free_rois_pixel))) ||
       (!(roiw_pixel = ensure_array(roiw_pixelo, &free_roiw_pixel))) ||
@@ -540,12 +547,12 @@ static PyObject *cube_wrapper(PyObject *module, PyObject *args) {
   nwave = (int) PyArray_Size((PyObject *) zc);
 
   ncube = nxx * nyy * nwave;
-  
+
   if (ncube ==0) {
     // 0-length input arrays. Nothing to clip. Return 0-length arrays
     spaxel_flux_arr = (PyArrayObject*) PyArray_EMPTY(1, &npy_ncube, NPY_DOUBLE, 0);
     if (!spaxel_flux_arr) goto fail;
-    
+
     spaxel_weight_arr = (PyArrayObject*) PyArray_EMPTY(1, &npy_ncube, NPY_DOUBLE, 0);
     if (!spaxel_weight_arr) goto fail;
 
@@ -556,9 +563,9 @@ static PyObject *cube_wrapper(PyObject *module, PyObject *args) {
     if (!spaxel_iflux_arr) goto fail;
 
     spaxel_dq_arr = (PyArrayObject*) PyArray_EMPTY(1, &npy_ncube, NPY_INT, 0);
-    if (!spaxel_dq_arr) goto fail;    
+    if (!spaxel_dq_arr) goto fail;
 
-    result = Py_BuildValue("(OOOOO)", spaxel_flux_arr, spaxel_weight_arr, spaxel_var_arr,
+    result = Py_BuildValue("(NNNNN)", spaxel_flux_arr, spaxel_weight_arr, spaxel_var_arr,
 			   spaxel_iflux_arr, spaxel_dq_arr);
 
     goto cleanup;
@@ -566,7 +573,7 @@ static PyObject *cube_wrapper(PyObject *module, PyObject *args) {
   }
 
   //______________________________________________________________________
-  // if flag_dq_plane = 1, Set up the dq plane 
+  // if flag_dq_plane = 1, Set up the dq plane
   //______________________________________________________________________
   int status1 = 0;
   if(flag_dq_plane){
@@ -600,7 +607,7 @@ static PyObject *cube_wrapper(PyObject *module, PyObject *args) {
     }
   } else{ // set dq plane to 0
     status1 = set_dqplane_to_zero(ncube, &spaxel_dq);
-    
+
   }
 
   //______________________________________________________________________
@@ -612,7 +619,7 @@ static PyObject *cube_wrapper(PyObject *module, PyObject *args) {
 			      (double *) PyArray_DATA(zc),
 			      (double *) PyArray_DATA(coord1),
 			      (double *) PyArray_DATA(coord2),
-			      (double *) PyArray_DATA(wave),			      
+			      (double *) PyArray_DATA(wave),
 			      (double *) PyArray_DATA(flux),
 			      (double *) PyArray_DATA(err),
 			      (double *) PyArray_DATA(rois_pixel),
@@ -627,7 +634,7 @@ static PyObject *cube_wrapper(PyObject *module, PyObject *args) {
 			     (double *) PyArray_DATA(zc),
 			     (double *) PyArray_DATA(coord1),
 			     (double *) PyArray_DATA(coord2),
-			     (double *) PyArray_DATA(wave),			      
+			     (double *) PyArray_DATA(wave),
 			     (double *) PyArray_DATA(flux),
 			     (double *) PyArray_DATA(err),
 			     (double *) PyArray_DATA(rois_pixel),
@@ -646,7 +653,7 @@ static PyObject *cube_wrapper(PyObject *module, PyObject *args) {
   } else {
     // create return tuple:
     npy_ncube = (npy_intp) ncube;
-    
+
     spaxel_flux_arr = (PyArrayObject*) PyArray_SimpleNewFromData(1, &npy_ncube, NPY_DOUBLE, spaxel_flux);
     if (!spaxel_flux_arr) goto fail;
     spaxel_flux = NULL;
@@ -654,11 +661,11 @@ static PyObject *cube_wrapper(PyObject *module, PyObject *args) {
     spaxel_weight_arr = (PyArrayObject*) PyArray_SimpleNewFromData(1, &npy_ncube, NPY_DOUBLE, spaxel_weight);
     if (!spaxel_weight_arr) goto fail;
     spaxel_weight = NULL;
-    
+
     spaxel_var_arr = (PyArrayObject*) PyArray_SimpleNewFromData(1, &npy_ncube, NPY_DOUBLE, spaxel_var);
     if (!spaxel_var_arr) goto fail;
     spaxel_var = NULL;
-    
+
     spaxel_iflux_arr = (PyArrayObject*) PyArray_SimpleNewFromData(1, &npy_ncube, NPY_DOUBLE, spaxel_iflux);
     if (!spaxel_iflux_arr) goto fail;
     spaxel_iflux = NULL;
@@ -672,11 +679,11 @@ static PyObject *cube_wrapper(PyObject *module, PyObject *args) {
     PyArray_ENABLEFLAGS(spaxel_var_arr, NPY_ARRAY_OWNDATA);
     PyArray_ENABLEFLAGS(spaxel_iflux_arr, NPY_ARRAY_OWNDATA);
     PyArray_ENABLEFLAGS(spaxel_dq_arr, NPY_ARRAY_OWNDATA);
-    result = Py_BuildValue("(OOOOO)", spaxel_flux_arr, spaxel_weight_arr, spaxel_var_arr,
+    result = Py_BuildValue("(NNNNN)", spaxel_flux_arr, spaxel_weight_arr, spaxel_var_arr,
 			   spaxel_iflux_arr, spaxel_dq_arr);
-	
+
     goto cleanup;
-    
+
   }
 
  fail:
