@@ -7,23 +7,29 @@ import logging
 
 import numpy as np
 
+from astropy.modeling import bind_bounding_box
 from astropy.modeling.models import Shift, Const1D, Mapping
 from gwcs.wcstools import grid_from_bounding_box
 from gwcs.utils import _toindex
 
-from .. import datamodels
-from ..assign_wcs import util
-from ..datamodels import WavelengthrangeModel
+from stdatamodels.jwst import datamodels
+from stdatamodels.jwst.datamodels import WavelengthrangeModel, ImageModel, SlitModel
+from stdatamodels.jwst.transforms.models import IdealToV2V3
+from astropy.modeling import CompoundModel
+
+from jwst.assign_wcs import util
 
 log = logging.getLogger(__name__)
 log.setLevel(logging.DEBUG)
 
 
-def extract_tso_object(input_model,
-                       reference_files=None,
-                       tsgrism_extract_height=None,
-                       extract_orders=None,
-                       compute_wavelength=True):
+def extract_tso_object(
+    input_model,
+    reference_files=None,
+    tsgrism_extract_height=None,
+    extract_orders=None,
+    compute_wavelength=True,
+):
     """
     Extract the spectrum for a NIRCam TSO grism observation.
 
@@ -53,7 +59,7 @@ def extract_tso_object(input_model,
     Returns
     -------
     output_model : `~jwst.datamodels.SlitModel`
-
+        Output SlitModel DataModel containing extracted spectrum
 
     Notes
     -----
@@ -72,25 +78,23 @@ def extract_tso_object(input_model,
 
     https://jwst-docs.stsci.edu/near-infrared-camera/nircam-observing-modes/nircam-time-series-observations/nircam-grism-time-series
     """
-
     # Check for reference files
     if not isinstance(reference_files, dict):
         raise TypeError("Expected a dictionary for reference_files")
 
     # Check for wavelengthrange reference file
-    if 'wavelengthrange' not in reference_files:
+    if "wavelengthrange" not in reference_files:
         raise KeyError("No wavelengthrange reference file specified")
 
     # If an extraction height is not supplied, default to entire
     # cross-dispersion size of the data array
     if tsgrism_extract_height is None:
         tsgrism_extract_height = input_model.meta.subarray.ysize
-    log.info("Setting extraction height to {}".format(tsgrism_extract_height))
+    log.info(f"Setting extraction height to {tsgrism_extract_height}")
 
     # Get the disperser parameters that have the wave limits
-    with WavelengthrangeModel(reference_files['wavelengthrange']) as f:
-        if (f.meta.instrument.name != 'NIRCAM' or
-                f.meta.exposure.type != 'NRC_TSGRISM'):
+    with WavelengthrangeModel(reference_files["wavelengthrange"]) as f:
+        if f.meta.instrument.name != "NIRCAM" or f.meta.exposure.type != "NRC_TSGRISM":
             raise ValueError("Wavelengthrange reference file is not for NIRCAM TSGRISM mode!")
         wavelengthrange = f.wavelengthrange
         ref_extract_orders = f.extract_orders
@@ -100,49 +104,58 @@ def extract_tso_object(input_model,
     if extract_orders is None:
         log.info("Using default order extraction from reference file")
         extract_orders = ref_extract_orders
-        available_orders = [x[1] for x in extract_orders if
-                            x[0] == input_model.meta.instrument.filter].pop()
+        available_orders = [
+            x[1] for x in extract_orders if x[0] == input_model.meta.instrument.filter
+        ].pop()
     else:
-        if (not isinstance(extract_orders, list) or
-                not all(isinstance(item, int) for item in extract_orders)):
+        if not isinstance(extract_orders, list) or not all(
+            isinstance(item, int) for item in extract_orders
+        ):
             raise TypeError("Expected extract_orders to be a list of integers.")
         available_orders = extract_orders
 
     if len(available_orders) > 1:
-        raise NotImplementedError("Multiple order extraction for TSO is "
-                                  "not currently implemented.")
+        raise NotImplementedError("Multiple order extraction for TSO is not currently implemented.")
 
     # Check for the existence of the aperture reference location meta data
-    if (input_model.meta.wcsinfo.siaf_xref_sci is None or
-            input_model.meta.wcsinfo.siaf_yref_sci is None):
-        raise ValueError('XREF_SCI and YREF_SCI are required for TSO mode.')
+    if (
+        input_model.meta.wcsinfo.siaf_xref_sci is None
+        or input_model.meta.wcsinfo.siaf_yref_sci is None
+    ):
+        raise ValueError("XREF_SCI and YREF_SCI are required for TSO mode.")
 
     # Create the extracted output as a SlitModel
-    log.info("Extracting order: {}".format(available_orders))
+    log.info(f"Extracting order: {available_orders}")
     output_model = datamodels.SlitModel()
     output_model.update(input_model)
     subwcs = copy.deepcopy(input_model.meta.wcs)
 
+    # (Some) NIRCam wavelengthrange entries have a fieldpoint entry, while NIRISS does not.
+    if len(wavelengthrange[0]) == 5:
+        filter_idx = 2
+    else:
+        filter_idx = 1
+
     # Loop over spectral orders
     for order in available_orders:
-        range_select = [(x[2], x[3]) for x in wavelengthrange if
-                        (x[0] == order and x[1] == input_model.meta.instrument.filter)]
+        range_select = [
+            (x[-2], x[-1])
+            for x in wavelengthrange
+            if (x[0] == order and x[filter_idx] == input_model.meta.instrument.filter)
+        ]
 
         # Use the filter that was in front of the grism for translation
         lmin, lmax = range_select.pop()
 
         # Create the order bounding box
-        source_xpos = input_model.meta.wcsinfo.siaf_xref_sci - 1  # remove FITS 1-indexed offset
-        source_ypos = input_model.meta.wcsinfo.siaf_yref_sci - 1  # remove FITS 1-indexed offset
-        transform = input_model.meta.wcs.get_transform('direct_image', 'grism_detector')
-        xmin, ymin, _ = transform(source_xpos,
-                                  source_ypos,
-                                  lmin,
-                                  order)
-        xmax, ymax, _ = transform(source_xpos,
-                                  source_ypos,
-                                  lmax,
-                                  order)
+        distortion = subwcs.get_transform("v2v3", "direct_image")
+        # 1-indexing already handled here
+        source_xpos, _ = compute_tso_offset_center(input_model, distortion)
+        # Remove FITS 1-indexed offset
+        source_ypos = input_model.meta.wcsinfo.siaf_yref_sci - 1
+        transform = input_model.meta.wcs.get_transform("direct_image", "grism_detector")
+        xmin, ymin, _ = transform(source_xpos, source_ypos, lmin, order)
+        xmax, ymax, _ = transform(source_xpos, source_ypos, lmax, order)
 
         # Add the shift to the lower corner to the subarray WCS object.
         # The shift should just be the lower bounding box corner.
@@ -150,9 +163,6 @@ def extract_tso_object(input_model,
         # model with the known object center and order information (in pixels of direct image)
         # This changes the user input to the model from (x,y,x0,y0,order) -> (x,y)
         #
-        # The bounding box is limited to the size of the detector in the dispersion direction
-        # and 64 pixels in the cross-dispersion direction (at request of instrument team).
-        #
         # The team wants the object to fall near row 34 for all cutouts, but the default cutout
         # height is 64 pixels (32 on either side). So bump the extraction ycenter, when necessary,
         # so that the height is 30 above and 34 below (in full frame) the object center.
@@ -176,6 +186,8 @@ def extract_tso_object(input_model,
             raise ValueError("Something bad happened calculating extraction y-size")
 
         # Limit the bounding box to the detector edges
+        # The bounding box is limited to the size of the detector in the dispersion direction
+        # and 64 pixels in the cross-dispersion direction (at request of instrument team).
         ymin, ymax = (max(extract_y_min, 0), min(extract_y_max, input_model.meta.subarray.ysize))
         xmin, xmax = (max(xmin, 0), min(xmax, input_model.meta.subarray.xsize))
 
@@ -197,40 +209,46 @@ def extract_tso_object(input_model,
 
         order_model = Const1D(order)
         order_model.inverse = Const1D(order)
-        tr = input_model.meta.wcs.get_transform('grism_detector', 'direct_image')
+        tr = input_model.meta.wcs.get_transform("grism_detector", "direct_image")
         tr = Mapping((0, 1, 0)) | Shift(xmin_ext) & Shift(ymin) & order_model | tr
-        subwcs.set_transform('grism_detector', 'direct_image', tr)
+        subwcs.set_transform("grism_detector", "direct_image", tr)
 
         xmin = int(xmin)
         xmax = int(xmax)
         ymin = int(ymin)
         ymax = int(ymax)
 
-        log.info("WCS made explicit for order: {}".format(order))
-        log.info("Spectral trace extents: (xmin: {}, ymin: {}), "
-                 "(xmax: {}, ymax: {})".format(xmin, ymin, xmax, ymax))
-        log.info("Extraction limits: (xmin: {}, ymin: {}), "
-                 "(xmax: {}, ymax: {})".format(xmin_ext, ymin, xmax_ext, ymax))
+        log.info(f"WCS made explicit for order: {order}")
+        log.info(
+            f"Spectral trace extents: (xmin: {xmin}, ymin: {ymin}), (xmax: {xmax}, ymax: {ymax})"
+        )
+        log.info(
+            f"Extraction limits: (xmin: {xmin_ext}, ymin: {ymin}), (xmax: {xmax_ext}, ymax: {ymax})"
+        )
 
         # Cut out the subarray from the input data arrays
-        ext_data = input_model.data[..., ymin: ymax + 1, xmin_ext:xmax_ext + 1].copy()
-        ext_err = input_model.err[..., ymin: ymax + 1, xmin_ext:xmax_ext + 1].copy()
-        ext_dq = input_model.dq[..., ymin: ymax + 1, xmin_ext:xmax_ext + 1].copy()
+        ext_data = input_model.data[..., ymin : ymax + 1, xmin_ext : xmax_ext + 1].copy()
+        ext_err = input_model.err[..., ymin : ymax + 1, xmin_ext : xmax_ext + 1].copy()
+        ext_dq = input_model.dq[..., ymin : ymax + 1, xmin_ext : xmax_ext + 1].copy()
         if input_model.var_poisson is not None and np.size(input_model.var_poisson) > 0:
-            var_poisson = input_model.var_poisson[..., ymin:ymax + 1, xmin_ext:xmax_ext + 1].copy()
+            var_poisson = input_model.var_poisson[
+                ..., ymin : ymax + 1, xmin_ext : xmax_ext + 1
+            ].copy()
         else:
             var_poisson = None
         if input_model.var_rnoise is not None and np.size(input_model.var_rnoise) > 0:
-            var_rnoise = input_model.var_rnoise[..., ymin:ymax + 1, xmin_ext:xmax_ext + 1].copy()
+            var_rnoise = input_model.var_rnoise[
+                ..., ymin : ymax + 1, xmin_ext : xmax_ext + 1
+            ].copy()
         else:
             var_rnoise = None
         if input_model.var_flat is not None and np.size(input_model.var_flat) > 0:
-            var_flat = input_model.var_flat[..., ymin:ymax + 1, xmin_ext:xmax_ext + 1].copy()
+            var_flat = input_model.var_flat[..., ymin : ymax + 1, xmin_ext : xmax_ext + 1].copy()
         else:
             var_flat = None
 
         # Finish populating the output model and meta data
-        if output_model.meta.model_type == "SlitModel":
+        if isinstance(output_model, SlitModel):
             output_model.data = ext_data
             output_model.err = ext_err
             output_model.dq = ext_dq
@@ -239,15 +257,15 @@ def extract_tso_object(input_model,
             output_model.var_flat = var_flat
             output_model.meta.wcs = subwcs
             output_model.meta.wcs.bounding_box = util.wcs_bbox_from_shape(ext_data.shape)
-            output_model.meta.wcsinfo.siaf_yref_sci = 34  # update for the move, vals are the same
-            output_model.meta.wcsinfo.siaf_xref_sci = input_model.meta.wcsinfo.siaf_xref_sci
-            output_model.meta.wcsinfo.spectral_order = order
-            output_model.meta.wcsinfo.dispersion_direction = \
-                input_model.meta.wcsinfo.dispersion_direction
             if compute_wavelength:
-                log.debug("Computing wavelengths (this takes a while ...)")
-                output_model.wavelength = compute_wavelength_array(output_model)
-            output_model.name = '1'
+                output_model.wavelength = compute_tso_wavelength_array(output_model)
+            output_model.meta.wcsinfo.siaf_yref_sci = 34  # update for the move, vals are the same
+            output_model.meta.wcsinfo.siaf_xref_sci = source_xpos + 1  # back to 1-indexed
+            output_model.meta.wcsinfo.spectral_order = order
+            output_model.meta.wcsinfo.dispersion_direction = (
+                input_model.meta.wcsinfo.dispersion_direction
+            )
+            output_model.name = "1"
             output_model.source_type = input_model.meta.target.source_type
             output_model.source_name = input_model.meta.target.catalog_name
             output_model.source_alias = input_model.meta.target.proposer_name
@@ -260,7 +278,7 @@ def extract_tso_object(input_model,
             output_model.source_id = 1
             output_model.bunit_data = input_model.meta.bunit_data
             output_model.bunit_err = input_model.meta.bunit_err
-            if hasattr(input_model, 'int_times'):
+            if hasattr(input_model, "int_times"):
                 output_model.int_times = input_model.int_times.copy()
 
     del subwcs
@@ -268,14 +286,16 @@ def extract_tso_object(input_model,
     return output_model
 
 
-def extract_grism_objects(input_model,
-                          grism_objects=None,
-                          reference_files=None,
-                          extract_orders=None,
-                          mmag_extract=None,
-                          compute_wavelength=True,
-                          wfss_extract_half_height=None,
-                          nbright=None):
+def extract_grism_objects(
+    input_model,
+    grism_objects=None,
+    reference_files=None,
+    extract_orders=None,
+    mmag_extract=None,
+    compute_wavelength=True,
+    wfss_extract_half_height=None,
+    nbright=None,
+):
     """
     Extract 2d boxes around each objects spectra for each order.
 
@@ -310,7 +330,7 @@ def extract_grism_objects(input_model,
     Returns
     -------
     output_model : `~jwst.datamodels.MultiSlitModel`
-
+        Output MultiSlitModel DataModel of extracted spectra
 
     Notes
     -----
@@ -360,24 +380,31 @@ def extract_grism_objects(input_model,
 
     if grism_objects is None:
         # get the wavelengthrange reference file from the input_model
-        if ('wavelengthrange' not in reference_files or
-                reference_files['wavelengthrange'] in ['N/A', '']):
+        if "wavelengthrange" not in reference_files or reference_files["wavelengthrange"] in [
+            "N/A",
+            "",
+        ]:
             raise ValueError("Expected name of wavelengthrange reference file")
         else:
-            grism_objects = util.create_grism_bbox(input_model, reference_files,
-                                                   extract_orders=extract_orders,
-                                                   mmag_extract=mmag_extract,
-                                                   wfss_extract_half_height=wfss_extract_half_height,
-                                                   nbright=nbright)
-            log.info("Grism object list created from source catalog: {0:s}"
-                     .format(input_model.meta.source_catalog))
+            grism_objects = util.create_grism_bbox(
+                input_model,
+                reference_files,
+                extract_orders=extract_orders,
+                mmag_extract=mmag_extract,
+                wfss_extract_half_height=wfss_extract_half_height,
+                nbright=nbright,
+            )
+            log.info(
+                f"Grism object list created from source catalog: \
+                {input_model.meta.source_catalog}"
+            )
 
     if not isinstance(grism_objects, list):
         raise TypeError("Expected input grism objects to be a list")
     if len(grism_objects) == 0:
         raise ValueError("No grism objects created from source catalog")
 
-    log.info("Extracting %d grism objects", len(grism_objects))
+    log.info(f"Extracting {len(grism_objects)} grism objects")
     output_model = datamodels.MultiSlitModel()
     output_model.update(input_model)
 
@@ -402,7 +429,6 @@ def extract_grism_objects(input_model,
     slits = []
     for obj in grism_objects:
         for order in obj.order_bounding.keys():
-
             # Add the shift to the lower corner to each subarray WCS object
             # The shift should just be the lower bounding box corner
             # also replace the object center location inputs to the GrismDispersion
@@ -412,7 +438,7 @@ def extract_grism_objects(input_model,
             # The bounding boxes here are also limited to the size of the detector
             # The check for boxes entirely off the detector is done in create_grism_bbox right now
             y, x = obj.order_bounding[order]
-            log.debug(f'YYY, {y}, {clamp(y[0], 0, input_model.meta.subarray.ysize)}')
+            log.debug(f"YYY, {y}, {clamp(y[0], 0, input_model.meta.subarray.ysize)}")
 
             # limit the boxes to the detector
             ymin = clamp(y[0], 0, input_model.meta.subarray.ysize)
@@ -425,9 +451,10 @@ def extract_grism_objects(input_model,
             # row or column of the detector
             if ymax - ymin > 0 and xmax - xmin > 0:
                 subwcs = copy.deepcopy(inwcs)
-                log.info("Subarray extracted for obj: {} order: {}:".format(obj.sid, order))
-                log.info("Subarray extents are: "
-                         "(xmin:{}, xmax:{}), (ymin:{}, ymax:{})".format(xmin, xmax, ymin, ymax))
+                log.info(f"Subarray extracted for obj: {obj.sid} order: {order}:")
+                log.info(
+                    f"Subarray extents are: (xmin:{xmin}, xmax:{xmax}), (ymin:{ymin}, ymax:{ymax})"
+                )
 
                 # only the first two numbers in the Mapping are used
                 # the order and source position are put directly into
@@ -441,12 +468,12 @@ def extract_grism_objects(input_model,
                 order_model = Const1D(order)
                 order_model.inverse = Const1D(order)
 
-                tr = inwcs.get_transform('grism_detector', 'detector')
-                tr = Mapping((0, 1, 0, 0, 0)) | (Shift(xmin) & Shift(ymin) &
-                                                 xcenter_model &
-                                                 ycenter_model &
-                                                 order_model) | tr
-
+                tr = inwcs.get_transform("grism_detector", "detector")
+                tr = (
+                    Mapping((0, 1, 0, 0, 0))
+                    | (Shift(xmin) & Shift(ymin) & xcenter_model & ycenter_model & order_model)
+                    | tr
+                )
                 y_slice = slice(_toindex(ymin), _toindex(ymax) + 1)
                 x_slice = slice(_toindex(xmin), _toindex(xmax) + 1)
 
@@ -466,29 +493,35 @@ def extract_grism_objects(input_model,
                 else:
                     var_flat = None
 
-                tr.bounding_box = util.transform_bbox_from_shape(ext_data.shape)
-                subwcs.set_transform('grism_detector', 'detector', tr)
+                bind_bounding_box(
+                    tr, util.transform_bbox_from_shape(ext_data.shape, order="F"), order="F"
+                )
+                subwcs.set_transform("grism_detector", "detector", tr)
 
-                new_slit = datamodels.SlitModel(data=ext_data,
-                                                err=ext_err,
-                                                dq=ext_dq,
-                                                var_poisson=var_poisson,
-                                                var_rnoise=var_rnoise,
-                                                var_flat=var_flat)
+                new_slit = datamodels.SlitModel(
+                    data=ext_data,
+                    err=ext_err,
+                    dq=ext_dq,
+                    var_poisson=var_poisson,
+                    var_rnoise=var_rnoise,
+                    var_flat=var_flat,
+                )
                 new_slit.meta.wcsinfo.spectral_order = order
-                new_slit.meta.wcsinfo.dispersion_direction = \
+                new_slit.meta.wcsinfo.dispersion_direction = (
                     input_model.meta.wcsinfo.dispersion_direction
+                )
                 new_slit.meta.wcsinfo.specsys = input_model.meta.wcsinfo.specsys
                 new_slit.meta.coordinates = input_model.meta.coordinates
                 new_slit.meta.wcs = subwcs
+
                 if compute_wavelength:
                     log.debug("Computing wavelengths")
-                    new_slit.wavelength = compute_wavelength_array(new_slit)
+                    new_slit.wavelength = compute_wfss_wavelength(new_slit)
 
                 # set x/ystart values relative to the image (screen) frame.
                 # The overall subarray offset is recorded in model.meta.subarray.
                 # nslit = obj.sid - 1  # catalog id starts at zero
-                new_slit.name = "{0}".format(obj.sid)
+                new_slit.name = f"{obj.sid}"
                 new_slit.is_extended = obj.is_extended
                 new_slit.xstart = _toindex(xmin) + 1  # fits pixels
                 new_slit.xsize = ext_data.shape[1]
@@ -497,6 +530,8 @@ def extract_grism_objects(input_model,
                 new_slit.source_xpos = float(obj.xcentroid)
                 new_slit.source_ypos = float(obj.ycentroid)
                 new_slit.source_id = obj.sid
+                new_slit.source_dec = obj.sky_centroid.dec.value
+                new_slit.source_ra = obj.sky_centroid.ra.value
                 new_slit.bunit_data = input_model.meta.bunit_data
                 new_slit.bunit_err = input_model.meta.bunit_err
                 slits.append(new_slit)
@@ -553,14 +588,13 @@ def compute_dispersion(wcs):
     -------
     dispersion : ndarray-like
         The pixel dispersion [in m].
-
     """
     raise NotImplementedError
 
 
-def compute_wavelength_array(slit):
+def compute_tso_wavelength_array(slit):
     """
-    Compute the wavelength array for a slit with gwcs object
+    Compute the wavelength array for a slit with gwcs object.
 
     Parameters
     ----------
@@ -572,7 +606,71 @@ def compute_wavelength_array(slit):
     wavelength : numpy.array
         The wavelength array
     """
-    transform = slit.meta.wcs.forward_transform
+    wcs = slit.meta.wcs
+    full_transform = slit.meta.wcs.forward_transform
+    x, y = grid_from_bounding_box(wcs.bounding_box)
+    wavelength = full_transform(x, y)[2]
+    return wavelength
+
+
+def compute_tso_offset_center(
+    input_model: ImageModel, distortion: CompoundModel
+) -> tuple[float, float]:
+    """
+    Accurately compute the offset between the source position and aperture center.
+
+    In the case that an Offset Special Requirement is requested in the APT,
+    the source is no longer at the aperture reference point.
+    The dither.x_offset and dither.y_offset values encode the offset
+    in units of arcseconds. They need to be translated from Ideal to
+    detector coordinates and into pixel units.
+
+    Parameters
+    ----------
+    input_model : ImageModel
+        The input data model
+    distortion : DistortionModel
+        The distortion model
+
+    Returns
+    -------
+    xc, yc : tuple
+        The x and y center of the image in direct image coordinates
+
+    Notes
+    -----
+    The wavelength is not used for the distortion calculation between
+    v2v3 and direct image coordinates, so this can be hardcoded to NaN.
+    """
+    idltov23 = IdealToV2V3(
+        input_model.meta.wcsinfo.v3yangle,
+        input_model.meta.wcsinfo.v2_ref,
+        input_model.meta.wcsinfo.v3_ref,
+        input_model.meta.wcsinfo.vparity,
+    )
+    v2_offset, v3_offset = idltov23(
+        input_model.meta.dither.x_offset, input_model.meta.dither.y_offset
+    )
+    wavelength = np.nan
+    xc, yc, _, _ = distortion(v2_offset, v3_offset, wavelength, 1)
+
+    return xc, yc
+
+
+def compute_wfss_wavelength(slit):
+    """
+    Compute the wavelength array for a slit with gwcs object.
+
+    Parameters
+    ----------
+    slit : `~jwst.datamodels.SlitModel`
+        JWST slit datamodel containing a meta.wcs GWCS object
+
+    Returns
+    -------
+    wavelength : numpy.array
+        The wavelength array
+    """
     x, y = grid_from_bounding_box(slit.meta.wcs.bounding_box)
-    wavelength = transform(x, y)[2]
+    wavelength = slit.meta.wcs(x, y)[2]
     return wavelength
