@@ -1,12 +1,11 @@
-"""
-Access the JWST Engineering Mnemonic Database through direct connection
-"""
+"""Access the JWST Engineering Mnemonic Database through direct connection."""
 
-from astropy.time import Time
 import logging
-from os import getenv
 import re
+from os import getenv
+
 import requests
+from astropy.time import Time
 from requests.adapters import HTTPAdapter, Retry
 
 from .engdb_lib import EngDB_Value, EngdbABC, FORCE_STATUSES, RETRIES, TIMEOUT
@@ -20,30 +19,28 @@ logger.addHandler(logging.NullHandler())
 # #############################################
 
 # URI paths necessary to access the db
-ENGDB_DATA = 'Data/'
-ENGDB_DATA_XML = 'xml/Data/'
-ENGDB_METADATA = 'MetaData/TlmMnemonics/'
-ENGDB_METADATA_XML = 'xml/MetaData/TlmMnemonics/'
+ENGDB_DATA = "Data/"
+ENGDB_DATA_XML = "xml/Data/"
+ENGDB_METADATA = "MetaData/TlmMnemonics/"
+ENGDB_METADATA_XML = "xml/MetaData/TlmMnemonics/"
 
-__all__ = [
-    'EngdbDirect'
-]
+__all__ = ["EngdbDirect"]
 
 
 class EngdbDirect(EngdbABC):
     """
-    Access the JWST Engineering Database through direct connection
+    Access the JWST Engineering Database through direct connection.
 
     Parameters
     ----------
     base_url : str
-        The base url for the engineering RESTful service
+        The base url for the engineering RESTful service.
 
     default_format : str
         The format the results of the data should be returned from the service.
-        If 'dict', the result will be in Python dict format.
+        If ``'dict'``, the result will be in Python dictionary format.
 
-    service_kwargs : dict
+    **service_kwargs : dict
         Service-specific keyword arguments that are not relevant to this implementation
         of EngdbABC.
     """
@@ -63,8 +60,8 @@ class EngdbDirect(EngdbABC):
     #: The start time of the last query.
     starttime = None
 
-    def __init__(self, base_url=None, default_format='dict', **service_kwargs):
-        logger.debug('kwargs not used by this service: %s', service_kwargs)
+    def __init__(self, base_url=None, default_format="dict", **service_kwargs):
+        logger.debug("kwargs not used by this service: %s", service_kwargs)
 
         self.configure(base_url=base_url)
 
@@ -73,71 +70,72 @@ class EngdbDirect(EngdbABC):
         self.set_session()
 
         # Check for aliveness
-        response = self._session.get(''.join([
-            self.base_url,
-            self.default_format,
-            ENGDB_METADATA
-        ]), timeout=self.timeout)
+        response = self._session.get(
+            "".join([self.base_url, self.default_format, ENGDB_METADATA]), timeout=self.timeout
+        )
         response.raise_for_status()
 
-    @property
-    def default_format(self):
+    @property  # type: ignore[no-redef]
+    def default_format(self):  # noqa: F811
+        """Default return format."""  # numpydoc ignore=RT01
         return self._default_format
 
     @default_format.setter
     def default_format(self, result_format):
-        result_format += '/'
-        if result_format == 'dict/':
-            result_format = ''
+        result_format += "/"
+        if result_format == "dict/":
+            result_format = ""
         self._default_format = result_format
 
     def configure(self, base_url=None):
-        """Configure from parameters and environment
+        """
+        Configure from parameters and environment.
 
         Parameters
         ----------
         base_url : str
-            The base url for the engineering RESTful service
+            The base url for the engineering RESTful service.
         """
         # Determine the database to use.
         if base_url is None:
-            base_url = getenv('ENG_BASE_URL')
+            base_url = getenv("ENG_BASE_URL")
         if not base_url:
-            raise RuntimeError('No engineering database URL given.')
-        if base_url[-1] != '/':
-            base_url += '/'
+            raise RuntimeError("No engineering database URL given.")
+        if base_url[-1] != "/":
+            base_url += "/"
         self.base_url = base_url
 
         # Get various timeout parameters
-        self.retries = getenv('ENG_RETRIES', RETRIES)
-        self.timeout = getenv('ENG_TIMEOUT', TIMEOUT)
+        self.retries = getenv("ENG_RETRIES", RETRIES)
+        self.timeout = getenv("ENG_TIMEOUT", TIMEOUT)
 
-    def get_meta(self, mnemonic='', result_format=None):
-        """Get the mnemonics meta info
+    def get_meta(self, mnemonic="", result_format=None):
+        """
+        Get the mnemonics meta info.
 
         Parameters
         ----------
         mnemonic : str
-            The engineering mnemonic to retrieve
+            The engineering mnemonic to retrieve.
 
         result_format : str
             The format to request from the service.
             If None, the `default_format` is used.
+
+        Returns
+        -------
+        response_json : dict
+            Meta info as JSON.
         """
         if result_format is None:
             result_format = self.default_format
 
-        query = ''.join([
-            self.base_url,
-            result_format,
-            ENGDB_METADATA,
-            mnemonic
-        ])
-        logger.debug('Query URL="{}"'.format(query))
+        query = "".join([self.base_url, result_format, ENGDB_METADATA, mnemonic])
+        logger.debug('Query URL="%s"', query)
 
         # Make our request
         response = self._session.get(query, timeout=self.timeout)
-        logger.debug('Response="{}"'.format(response))
+        logger.debug('Response="%s"', response)
         response.raise_for_status()
 
         # That's all folks
@@ -145,14 +143,14 @@ class EngdbDirect(EngdbABC):
         return response.json()
 
     def get_values(
-            self,
-            mnemonic,
-            starttime,
-            endtime,
-            time_format=None,
-            include_obstime=False,
-            include_bracket_values=False,
-            zip_results=True
+        self,
+        mnemonic,
+        starttime,
+        endtime,
+        time_format=None,
+        include_obstime=False,
+        include_bracket_values=False,
+        zip_results=True,
     ):
         """
         Retrieve all results for a mnemonic in the requested time range.
@@ -160,7 +158,7 @@ class EngdbDirect(EngdbABC):
         Parameters
         ----------
         mnemonic : str
-            The engineering mnemonic to retrieve
+            The engineering mnemonic to retrieve.
 
         starttime : str or `astropy.time.Time`
             The, inclusive, start time to retrieve from.
@@ -194,50 +192,39 @@ class EngdbDirect(EngdbABC):
         Raises
         ------
         requests.exceptions.HTTPError
-            Either a bad URL or non-existant mnemonic.
+            Either a bad URL or non-existent mnemonic.
         """
         records = self._get_records(
-            mnemonic=mnemonic,
-            starttime=starttime,
-            endtime=endtime,
-            time_format=time_format
+            mnemonic=mnemonic, starttime=starttime, endtime=endtime, time_format=time_format
         )
 
         # Records returned are apparent not strictly correlated with
         # observation time. So, need to filter further.
-        db_starttime = extract_db_time(records['ReqSTime'])
-        db_endtime = extract_db_time(records['ReqETime'])
-        results = _ValueCollection(
-            include_obstime=include_obstime,
-            zip_results=zip_results
-        )
-        if records['Data'] is not None:
-            for record in records['Data']:
-                obstime = extract_db_time(record['ObsTime'])
+        db_starttime = extract_db_time(records["ReqSTime"])
+        db_endtime = extract_db_time(records["ReqETime"])
+        results = _ValueCollection(include_obstime=include_obstime, zip_results=zip_results)
+        if records["Data"] is not None:
+            for record in records["Data"]:
+                obstime = extract_db_time(record["ObsTime"])
                 if not include_bracket_values:
                     if obstime < db_starttime or obstime > db_endtime:
                         continue
-                value = record['EUValue']
+                value = record["EUValue"]
                 results.append(obstime, value)
 
         return results.collection
 
     def set_session(self):
-        """Setup HTTP session"""
+        """Set up HTTP session."""
         s = requests.Session()
-        retries = Retry(total=10, backoff_factor=1.0, status_forcelist=FORCE_STATUSES, raise_on_status=True)
-        s.mount('https://', HTTPAdapter(max_retries=retries))
+        retries = Retry(
+            total=10, backoff_factor=1.0, status_forcelist=FORCE_STATUSES, raise_on_status=True
+        )
+        s.mount("https://", HTTPAdapter(max_retries=retries))
 
         self._session = s
 
-    def _get_records(
-            self,
-            mnemonic,
-            starttime,
-            endtime,
-            result_format=None,
-            time_format=None
-    ):
+    def _get_records(self, mnemonic, starttime, endtime, result_format=None, time_format=None):
         """
         Retrieve all results for a mnemonic in the requested time range.
 
@@ -270,7 +257,7 @@ class EngdbDirect(EngdbABC):
         Raises
         ------
         requests.exceptions.HTTPError
-            Either a bad URL or non-existant mnemonic.
+            Either a bad URL or non-existent mnemonic.
 
         Notes
         -----
@@ -288,22 +275,24 @@ class EngdbDirect(EngdbABC):
         self.endtime = endtime
 
         # Build the URL
-        query = ''.join([
-            self.base_url,
-            result_format,
-            'Data/',
-            mnemonic,
-            '?sTime=',
-            starttime.iso,
-            '&eTime=',
-            endtime.iso,
-        ])
-        logger.debug('Query URL="{}"'.format(query))
+        query = "".join(
+            [
+                self.base_url,
+                result_format,
+                "Data/",
+                mnemonic,
+                "?sTime=",
+                starttime.iso,
+                "&eTime=",
+                endtime.iso,
+            ]
+        )
+        logger.debug('Query URL="%s"', query)
 
         # Make our request
         response = self._session.get(query, timeout=self.timeout)
-        logger.debug('Response: %s', response)
-        logger.debug('Response: %s', response.json())
+        logger.debug("Response: %s", response)
+        logger.debug("Response: %s", response.json())
         response.raise_for_status()
 
         # That's all folks
@@ -311,8 +300,9 @@ class EngdbDirect(EngdbABC):
         return response.json()
 
 
-class _ValueCollection():
-    """Engineering Value Collection
+class _ValueCollection:
+    """
+    Engineering Value Collection.
 
     Parameters
     ----------
@@ -325,13 +315,13 @@ class _ValueCollection():
         will be a list of 2-tuples. If false, the return will
         be a single 2-tuple, where each element is a list.
 
-
     Attributes
     ----------
     collection : [value, ...] or [(obstime, value), ...] or ([obstime,...], [value, ...])
         Returns the list of values.
         See `include_obstime` and `zip_results` for modifications.
     """
+
     def __init__(self, include_obstime=False, zip_results=True):
         self._include_obstime = include_obstime
         self._zip_results = zip_results
@@ -342,10 +332,12 @@ class _ValueCollection():
     @property
     def collection(self):
         if self._include_obstime:
-            obstimes = Time(self.obstimes, format='unix')
-            obstimes.format = 'isot'
+            obstimes = Time(self.obstimes, format="unix")
+            obstimes.format = "isot"
             if self._zip_results:
-                collection = [EngDB_Value(t, v) for t, v in zip(obstimes, self.values)]
+                collection = [
+                    EngDB_Value(t, v) for t, v in zip(obstimes, self.values, strict=False)
+                ]
             else:
                 collection = EngDB_Value(obstimes, self.values)
         else:
@@ -353,7 +345,8 @@ class _ValueCollection():
         return collection
 
     def append(self, obstime, value):
-        """Append value to collection
+        """
+        Append value to collection.
 
         Parameters
         ----------
@@ -366,10 +359,10 @@ class _ValueCollection():
 
         Notes
         -----
-        The `obstime` is converted to an `astropy.time.Time`
+        The ``obstime`` is converted to an `astropy.time.Time`.
         """
         # Convert from milliseconds to seconds before appending.
-        self.obstimes.append(obstime / 1000.)
+        self.obstimes.append(obstime / 1000.0)
         self.values.append(value)
 
 
@@ -377,7 +370,8 @@ class _ValueCollection():
 # Utilities
 # #########
 def extract_db_time(db_date):
-    """Extract date from date string in the Database
+    """
+    Extract date from date string in the Database.
 
     Parameters
     ----------
@@ -387,18 +381,18 @@ def extract_db_time(db_date):
     Returns
     -------
     time : int
-        The UNIX time in milliseconds
+        The UNIX time in milliseconds.
 
     Notes
     -----
-    The format of time in the database is
+    The format of time in the database is::
 
         /Date(1234567890123+1234)/
 
     where the plus could be a minus. What is returned is
     the actual 13 digit number before the plus/minus.
     """
-    match = re.match(r'\/Date\((\d{13})(.*)\)\/', db_date)
+    match = re.match(r"\/Date\((\d{13})(.*)\)\/", db_date)
     milliseconds = int(match.group(1))
 
     return milliseconds
