@@ -1,15 +1,16 @@
-"""Engineering DB common library"""
+"""Engineering DB common library."""
+
 import abc
 from collections import namedtuple
 
-__all__ = ['EngDB_Value', 'EngdbABC']
+__all__ = ["EngDB_Value", "EngdbABC"]
 
 
 # Define the returned value tuple.
-EngDB_Value = namedtuple('EngDB_Value', ['obstime', 'value'])
+EngDB_Value = namedtuple("EngDB_Value", ["obstime", "value"])
 
 # Path templates
-DATA = '_data.json'
+DATA = "_data.json"
 
 # HTTP status that should get retries
 # For statuses, just blanket cover the 4xx and 5xx errors
@@ -20,7 +21,8 @@ TIMEOUT = 10 * 60  # 10 minutes
 
 
 class EngdbABC(abc.ABC):
-    """Access the JWST Engineering Database
+    """
+    Access the JWST Engineering Database.
 
     This is the minimal API for the service definition. Concrete implementations
     may provide other parameters and attributes.
@@ -28,33 +30,35 @@ class EngdbABC(abc.ABC):
     Parameters
     ----------
     base_url : str
-        The base url for the engineering RESTful service
+        The base url for the engineering RESTful service.
 
-    service_kwargs : dict
+    **service_kwargs : dict
         Service-specific keyword arguments. Refer to the concrete implementations
         of EngdbABC.
     """
+
     @property
     @abc.abstractmethod
     def base_url(self):
-        """The URL of the service in use"""
+        """The URL of the service in use."""
         pass
 
     @property
     @abc.abstractmethod
     def endtime(self):
-        """The endtime of the search"""
+        """The endtime of the search."""
         pass
 
     @property
     @abc.abstractmethod
     def response(self):
-        """The `requests.Response` information"""
+        """The `requests.Response` information."""
         pass
 
     @property
+    @abc.abstractmethod
     def starttime(self):
-        """The start time of the search"""
+        """The start time of the search."""
         pass
 
     @abc.abstractmethod
@@ -62,18 +66,19 @@ class EngdbABC(abc.ABC):
         pass
 
     @abc.abstractmethod
-    def get_meta(self, mnemonic='', **service_kwargs):
-        """Get the mnemonics meta info
+    def get_meta(self, mnemonic="", **service_kwargs):
+        """
+        Get the mnemonics meta info.
 
         Parameters
         ----------
         mnemonic : str
-            The engineering mnemonic to retrieve
+            The engineering mnemonic to retrieve.
 
         Returns
         -------
         meta : object
-            The meta information. Type of return is dependent on the type of service
+            The meta information. Type of return is dependent on the type of service.
 
         service_kwargs : dict
             Service-specific keyword arguments. Refer to the concrete implementations
@@ -82,15 +87,23 @@ class EngdbABC(abc.ABC):
         pass
 
     @abc.abstractmethod
-    def get_values(self, mnemonic, starttime, endtime,
-                   time_format=None, include_obstime=False, include_bracket_values=False, zip_results=True):
+    def get_values(
+        self,
+        mnemonic,
+        starttime,
+        endtime,
+        time_format=None,
+        include_obstime=False,
+        include_bracket_values=False,
+        zip_results=True,
+    ):
         """
         Retrieve all results for a mnemonic in the requested time range.
 
         Parameters
         ----------
         mnemonic : str
-            The engineering mnemonic to retrieve
+            The engineering mnemonic to retrieve.
 
         starttime : str or `astropy.time.Time`
             The, inclusive, start time to retrieve from.
@@ -124,18 +137,18 @@ class EngdbABC(abc.ABC):
         Raises
         ------
         requests.exceptions.HTTPError
-            Either a bad URL or non-existant mnemonic.
+            Either a bad URL or non-existent mnemonic.
         """
         pass
 
 
 def mnemonic_data_fname(mnemonic):
     """
-    Construct the file name for the cached data of the specified mnemonic
+    Construct the file name for the cached data of the specified mnemonic.
 
     Parameters
     ----------
-    mnemonic
+    mnemonic : str
         The mnemonic to refer to.
 
     Returns
