@@ -1,28 +1,31 @@
-'''
-This script adds velocity aberration correction information to the FITS
+"""
+Utilities for velocity aberration correction.
+
+Script to add velocity aberration correction information to the FITS
 files provided to it on the command line (one or more).
 
 It assumes the following keywords are present in the file header:
 
-JWST_DX (km/sec)
-JWST_DY (km/sec)
-JWST_DZ (km/sec)
-RA_REF (deg)
-DEC_REF (deg)
+* JWST_DX (km/sec)
+* JWST_DY (km/sec)
+* JWST_DZ (km/sec)
+* RA_REF (deg)
+* DEC_REF (deg)
 
 The keywords added are:
 
-VA_SCALE (dimensionless scale factor)
+* VA_SCALE (dimensionless scale factor)
 
 It does not currently place the new keywords in any particular location
 in the header other than what is required by the standard.
-'''
+"""
 
 import logging
 import numpy as np
-import astropy.io.fits as fits
 from gwcs.geometry import SphericalToCartesian, CartesianToSpherical
 from scipy.constants import speed_of_light
+import jwst.datamodels as dm
+from jwst.datamodels import Level1bModel  # type: ignore[attr-defined]
 
 # Configure logging
 logger = logging.getLogger(__name__)
@@ -32,8 +35,11 @@ SPEED_OF_LIGHT = speed_of_light / 1000  # km / s
 
 
 def compute_va_effects_vector(velocity_x, velocity_y, velocity_z, u):
-    """ Computes constant scale factor due to velocity aberration as well as
-    corrected ``RA`` and ``DEC`` values, in vector form
+    """
+    Compute velocity aberration effects scale factor.
+
+    Computes constant scale factor due to velocity aberration as well as
+    corrected ``RA`` and ``DEC`` values, in vector form.
 
     Parameters
     ----------
@@ -51,8 +57,8 @@ def compute_va_effects_vector(velocity_x, velocity_y, velocity_z, u):
 
     Returns
     -------
-    scale_factor: float
-        Multiply the nominal image scale (e.g. in degrees per pixel) by
+    scale_factor : float
+        Multiply the nominal image scale (e.g., in degrees per pixel) by
         this value to obtain the image scale corrected for the "aberration
         of starlight" due to the velocity of JWST with respect to the Sun.
 
@@ -62,7 +68,7 @@ def compute_va_effects_vector(velocity_x, velocity_y, velocity_z, u):
     beta = np.array([velocity_x, velocity_y, velocity_z]) / SPEED_OF_LIGHT
     beta2 = np.dot(beta, beta)  # |beta|^2
     if beta2 == 0.0:
-        logger.warning('Observatory speed is zero. Setting VA scale to 1.0')
+        logger.warning("Observatory speed is zero. Setting VA scale to 1.0")
         return 1.0, u
 
     u_beta = np.dot(u, beta)
@@ -77,18 +83,21 @@ def compute_va_effects_vector(velocity_x, velocity_y, velocity_z, u):
 
 
 def compute_va_effects(velocity_x, velocity_y, velocity_z, ra, dec):
-    """ Computes constant scale factor due to velocity aberration as well as
+    """
+    Compute velocity aberration effects.
+
+    Computes constant scale factor due to velocity aberration as well as
     corrected ``RA`` and ``DEC`` values.
 
     Parameters
     ----------
-    velocity_x, velocity_y, velocity_z: float
+    velocity_x, velocity_y, velocity_z : float
         The components of the velocity of JWST, in km / s with respect to
         the Sun.  These are celestial coordinates, with x toward the
         vernal equinox, y toward right ascension 90 degrees and declination
         0, z toward the north celestial pole.
 
-    ra, dec: float
+    ra, dec : float
         The right ascension and declination of the target (or some other
         point, such as the center of a detector) in the barycentric coordinate
         system.  The equator and equinox should be the same as the coordinate
@@ -96,17 +105,16 @@ def compute_va_effects(velocity_x, velocity_y, velocity_z, ra, dec):
 
     Returns
     -------
-    scale_factor: float
-        Multiply the nominal image scale (e.g. in degrees per pixel) by
+    scale_factor : float
+        Multiply the nominal image scale (e.g., in degrees per pixel) by
         this value to obtain the image scale corrected for the "aberration
         of starlight" due to the velocity of JWST with respect to the Sun.
 
-    apparent_ra: float
+    apparent_ra : float
         Apparent star position in the moving telescope frame.
 
-    apparent_dec: float
+    apparent_dec : float
         Apparent star position in the moving telescope frame.
-
     """
     u = np.asanyarray(SphericalToCartesian()(ra, dec))
     scale_factor, u_corr = compute_va_effects_vector(velocity_x, velocity_y, velocity_z, u)
@@ -114,29 +122,38 @@ def compute_va_effects(velocity_x, velocity_y, velocity_z, ra, dec):
     return scale_factor, apparent_ra, apparent_dec
 
 
-def add_dva(filename):
+def add_dva(filename, force_level1bmodel=True):
     """
+    Determine velocity aberration.
+
     Given the name of a valid partially populated level 1b JWST file,
     determine the velocity aberration scale factor and apparent target position
     in the moving (telescope) frame.
 
     It presumes all the accessed keywords are present (see first block).
-    """
-    hdulist = fits.open(filename, mode='update')
-    pheader = hdulist[0].header
-    sheader = hdulist['SCI'].header
 
-    # compute the velocity aberration information
+    Parameters
+    ----------
+    filename : str
+        The name of the file to be updated.
+    force_level1bmodel : bool, optional
+        If True, the input file will be force-opened as a Level1bModel.  If False,
+        the file will be opened using the generic DataModel.  The default is True.
+    """
+    if force_level1bmodel:
+        model = Level1bModel(filename)
+    else:
+        model = dm.open(filename)
     scale_factor, apparent_ra, apparent_dec = compute_va_effects(
-        velocity_x=sheader['JWST_DX'],
-        velocity_y=sheader['JWST_DY'],
-        velocity_z=sheader['JWST_DZ'],
-        ra=sheader['RA_REF'],
-        dec=sheader['DEC_REF']
+        velocity_x=model.meta.ephemeris.velocity_x_bary,
+        velocity_y=model.meta.ephemeris.velocity_y_bary,
+        velocity_z=model.meta.ephemeris.velocity_z_bary,
+        ra=model.meta.wcsinfo.ra_ref,
+        dec=model.meta.wcsinfo.dec_ref,
     )
 
     # update header
-    pheader['VA_RA'] = apparent_ra
-    pheader['VA_DEC'] = apparent_dec
-    sheader['VA_SCALE'] = scale_factor
-    hdulist.close()
+    model.meta.velocity_aberration.scale_factor = scale_factor
+    model.meta.velocity_aberration.va_ra_ref = apparent_ra
+    model.meta.velocity_aberration.va_dec_ref = apparent_dec
+    model.save(filename)
