@@ -1,11 +1,12 @@
 """
 Test script for set_velocity_aberration.py
 """
+
 import subprocess
 
 from numpy import isclose
 from astropy.io import fits
-
+import jwst.datamodels as dm
 from jwst.lib.set_velocity_aberration import compute_va_effects
 
 # Testing constants
@@ -30,21 +31,21 @@ def test_compute_va_effects_zero_velocity():
     assert isclose(va_dec, GOOD_POS[1], atol=1e-16)
 
 
-def test_velocity_aberration_script(tmpdir):
+def test_velocity_aberration_script(tmp_path):
     """Test the whole script on a FITS file"""
-    path = str(tmpdir.join("velocity_aberration_tmpfile.fits"))
-    hdulist = fits.HDUList([fits.PrimaryHDU(), fits.ImageHDU(name='SCI')])
-    hdulist['SCI'].header['JWST_DX'] = GOOD_VELOCITY[0]
-    hdulist['SCI'].header['JWST_DY'] = GOOD_VELOCITY[1]
-    hdulist['SCI'].header['JWST_DZ'] = GOOD_VELOCITY[2]
-    hdulist['SCI'].header['RA_REF'] = GOOD_POS[0]
-    hdulist['SCI'].header['DEC_REF'] = GOOD_POS[1]
-    hdulist.writeto(path)
-    hdulist.close()
 
-    subprocess.check_call(["set_velocity_aberration.py", path])
+    path = tmp_path / "velocity_aberration_tmpfile.fits"
+    model = dm.ImageModel()
+    model.meta.ephemeris.velocity_x_bary = GOOD_VELOCITY[0]
+    model.meta.ephemeris.velocity_y_bary = GOOD_VELOCITY[1]
+    model.meta.ephemeris.velocity_z_bary = GOOD_VELOCITY[2]
+    model.meta.wcsinfo.ra_ref = GOOD_POS[0]
+    model.meta.wcsinfo.dec_ref = GOOD_POS[1]
+    model.save(path)
+
+    subprocess.check_call(["set_velocity_aberration", path])
 
     with fits.open(path) as hdulist_in:
-        assert isclose(hdulist_in[0].header['VA_RA'], GOOD_APPARENT_RA, rtol=0, atol=1e-7)
-        assert isclose(hdulist_in[0].header['VA_DEC'], GOOD_APPARENT_DEC, rtol=0, atol=1e-7)
-        assert isclose(hdulist_in['SCI'].header['VA_SCALE'], GOOD_SCALE_FACTOR, rtol=0, atol=1e-7)
+        assert isclose(hdulist_in[0].header["VA_RA"], GOOD_APPARENT_RA, rtol=0, atol=1e-7)
+        assert isclose(hdulist_in[0].header["VA_DEC"], GOOD_APPARENT_DEC, rtol=0, atol=1e-7)
+        assert isclose(hdulist_in["SCI"].header["VA_SCALE"], GOOD_SCALE_FACTOR, rtol=0, atol=1e-7)
