@@ -9,7 +9,7 @@ import shutil
 import sys
 
 import asdf
-from astropy.io.fits.diff import FITSDiff
+from jwst.regtest.st_fitsdiff import STFITSDiff as FITSDiff
 from ci_watson.artifactory_helpers import (
     check_url,
     get_bigdata_root,
@@ -23,18 +23,30 @@ from jwst.lib.suffix import replace_suffix
 from jwst.pipeline.collect_pipeline_cfgs import collect_pipeline_cfgs
 from jwst.stpipe import Step
 
-# Define location of default Artifactory API key, for Jenkins use only
-ARTIFACTORY_API_KEY_FILE = '/eng/ssb2/keys/svc_rodata.key'
+# Define location of default Artifactory API key
+ARTIFACTORY_API_KEY_FILE = "/eng/ssb2/keys/svc_rodata.key"
 
 
 class RegtestData:
-    """Defines data paths on Artifactory and data retrieval methods"""
+    """Define data paths on Artifactory and data retrieval methods."""
 
-    def __init__(self, env="dev", inputs_root="jwst-pipeline",
-                 results_root="jwst-pipeline-results", docopy=True,
-                 input=None, input_remote=None, output=None, truth=None,
-                 truth_remote=None, remote_results_path=None, test_name=None,
-                 traceback=None, okify_op='file_copy', **kwargs):
+    def __init__(
+        self,
+        env="dev",
+        inputs_root="jwst-pipeline",
+        results_root="jwst-pipeline-results",
+        docopy=True,
+        input=None,
+        input_remote=None,
+        output=None,
+        truth=None,
+        truth_remote=None,
+        remote_results_path=None,
+        test_name=None,
+        traceback=None,
+        okify_op="file_copy",
+        **kwargs,
+    ):
         self.env = env
         self._inputs_root = inputs_root
         self._results_root = results_root
@@ -60,15 +72,23 @@ class RegtestData:
 
     def __repr__(self):
         return pprint.pformat(
-            dict(input=self.input, output=self.output, truth=self.truth,
-                 input_remote=self.input_remote, truth_remote=self.truth_remote,
-                 remote_results_path=self.remote_results_path, test_name=self.test_name,
-                 traceback=self.traceback, okify_op=self.okify_op),
-            indent=1
+            {
+                "input": self.input,
+                "output": self.output,
+                "truth": self.truth,
+                "input_remote": self.input_remote,
+                "truth_remote": self.truth_remote,
+                "remote_results_path": self.remote_results_path,
+                "test_name": self.test_name,
+                "traceback": self.traceback,
+                "okify_op": self.okify_op,
+            },
+            indent=1,
         )
 
     @property
-    def input_remote(self):
+    def input_remote(self):  # numpydoc ignore=RT01
+        """Return the remote input path."""
         if self._input_remote is not None:
             return os.path.join(*self._input_remote)
         else:
@@ -82,7 +102,8 @@ class RegtestData:
             self._input_remote = value
 
     @property
-    def truth_remote(self):
+    def truth_remote(self):  # numpydoc ignore=RT01
+        """Return the remote truth path."""
         if self._truth_remote is not None:
             return os.path.join(*self._truth_remote)
         else:
@@ -96,7 +117,8 @@ class RegtestData:
             self._truth_remote = value
 
     @property
-    def input(self):
+    def input(self):  # numpydoc ignore=RT01
+        """Return the local input path."""
         return self._input
 
     @input.setter
@@ -107,7 +129,8 @@ class RegtestData:
             self._input = value
 
     @property
-    def truth(self):
+    def truth(self):  # numpydoc ignore=RT01
+        """Return the local truth path."""
         return self._truth
 
     @truth.setter
@@ -118,7 +141,8 @@ class RegtestData:
             self._truth = value
 
     @property
-    def output(self):
+    def output(self):  # numpydoc ignore=RT01
+        """Return the local output path."""
         return self._output
 
     @output.setter
@@ -129,14 +153,32 @@ class RegtestData:
             self._output = value
 
     @property
-    def bigdata_root(self):
+    def bigdata_root(self):  # numpydoc ignore=RT01
+        """Return the root of the bigdata server."""
         return self._bigdata_root
 
     # The methods
     def get_data(self, path=None, docopy=None):
-        """Copy data from Artifactory remote resource to the CWD
+        """
+        Copy data from Artifactory remote resource to the CWD.
 
         Updates self.input and self.input_remote upon completion
+
+        Parameters
+        ----------
+        path : str, optional
+            The path to the input file that will be copied.
+        docopy : bool, optional
+            Switch to control whether or not to copy a file
+            into the test output directory when running the test.
+            If you wish to open the file directly from remote
+            location or just to set path to source, set this to `False`.
+            Default: `True`
+
+        Returns
+        -------
+        input : str
+            The full local path to the input file.
         """
         if path is None:
             path = self.input_remote
@@ -144,14 +186,28 @@ class RegtestData:
             self.input_remote = path
         if docopy is None:
             docopy = self.docopy
-        self.input = get_bigdata(self._inputs_root, self.env, path,
-                                 docopy=docopy)
+        self.input = get_bigdata(self._inputs_root, self.env, path, docopy=docopy)
         self.input_remote = os.path.join(self._inputs_root, self.env, path)
 
         return self.input
 
-    def data_glob(self, path=None, glob='*', docopy=None):
-        """Get a list of files"""
+    def data_glob(self, path=None, glob="*"):
+        """
+        Get a list of files from either a local path or URL.
+
+        Parameters
+        ----------
+        path : str, optional
+            The path to the input file that will be copied.
+            glob : str, optional
+            The glob pattern to use to search for files.
+            Default: `*`
+
+        Returns
+        -------
+        file_paths : [str[, ...]]
+            Full file paths that match the glob criterion
+        """
         if path is None:
             path = self.input_remote
         else:
@@ -169,19 +225,33 @@ class RegtestData:
             root_len = len(self.env) + 1
             file_paths = _data_glob_url(self._inputs_root, self.env, path, glob, root=root)
         else:
-            raise BigdataError('Path cannot be found: {}'.format(path))
+            raise BigdataError(f"Path cannot be found: {path}")
 
         # Remove the root from the paths
-        file_paths = [
-            file_path[root_len:]
-            for file_path in file_paths
-        ]
+        file_paths = [file_path[root_len:] for file_path in file_paths]
         return file_paths
 
     def get_truth(self, path=None, docopy=None):
-        """Copy truth data from Artifactory remote resource to the CWD/truth
+        """
+        Copy truth data from Artifactory remote resource to the CWD/truth.
 
         Updates self.truth and self.truth_remote on completion
+
+        Parameters
+        ----------
+        path : str, optional
+            The path to the truth file that will be copied.
+        docopy : bool, optional
+            Switch to control whether or not to copy a file
+            into the test output directory when running the test.
+            If you wish to open the file directly from remote
+            location or just to set path to source, set this to `False`.
+            Default: `True`
+
+        Returns
+        -------
+        str
+            The local path to the truth file.
         """
         if path is None:
             path = self.truth_remote
@@ -189,23 +259,22 @@ class RegtestData:
             self.truth_remote = path
         if docopy is None:
             docopy = self.docopy
-        os.makedirs('truth', exist_ok=True)
-        with pushdir('truth'):
-            self.truth = get_bigdata(self._inputs_root, self.env, path,
-                                     docopy=docopy)
+        os.makedirs("truth", exist_ok=True)
+        with pushdir("truth"):
+            self.truth = get_bigdata(self._inputs_root, self.env, path, docopy=docopy)
             self.truth_remote = os.path.join(self._inputs_root, self.env, path)
 
         return self.truth
 
     def get_asn(self, path=None, docopy=True, get_members=True):
-        """Copy association and association members from Artifactory remote
-        resource to the CWD/truth.
+        """
+        Copy association and association members from Artifactory remote resource to the CWD/truth.
 
         Updates self.input and self.input_remote upon completion
 
         Parameters
         ----------
-        path: str
+        path : str
             The remote path
 
         docopy : bool
@@ -215,7 +284,7 @@ class RegtestData:
             location or just to set path to source, set this to `False`.
             Default: `True`
 
-        get_members: bool
+        get_members : bool
             If an association is the input, retrieve the members.
             Otherwise, do not.
         """
@@ -227,47 +296,58 @@ class RegtestData:
             docopy = self.docopy
 
         # Get the association JSON file
-        self.input = get_bigdata(self._inputs_root, self.env, path,
-                                 docopy=docopy)
+        self.input = get_bigdata(self._inputs_root, self.env, path, docopy=docopy)
         with open(self.input) as fp:
             asn = load_asn(fp)
             self.asn = asn
 
         # Get each member in the association as well
         if get_members:
-            for product in asn['products']:
-                for member in product['members']:
-                    fullpath = os.path.join(
-                        os.path.dirname(self.input_remote),
-                        member['expname'])
-                    get_bigdata(self._inputs_root, self.env, fullpath,
-                                docopy=self.docopy)
+            for product in asn["products"]:
+                for member in product["members"]:
+                    fullpath = os.path.join(os.path.dirname(self.input_remote), member["expname"])
+                    get_bigdata(self._inputs_root, self.env, fullpath, docopy=self.docopy)
 
     def to_asdf(self, path):
-        tree = eval(str(self))
+        """Write the RegtestData object to an ASDF file."""
+        tree = eval(str(self))  # noqa: S307
         af = asdf.AsdfFile(tree=tree)
         af.write_to(path)
 
     @classmethod
     def open(cls, filename):
+        """
+        Read a RegtestData object from an ASDF file.
+
+        Parameters
+        ----------
+        filename : str
+            The path to the ASDF file
+
+        Returns
+        -------
+        `jwst.regtest.regtestdata.RegtestData`
+            The RegtestData object
+        """
         with asdf.open(filename) as af:
             return cls(**af.tree)
 
 
 def run_step_from_dict(rtdata, **step_params):
-    """Run Steps with given parameter
+    """
+    Run Step on regression test data from a dictionary of input parameters.
 
     Parameters
     ----------
-    rtdata: RegtestData
+    rtdata : RegtestData
         The artifactory instance
 
-    step_params: dict
+    **step_params : dict
         The parameters defining what step to run with what input
 
     Returns
     -------
-    rtdata: RegtestData
+    rtdata : RegtestData
         Updated `RegtestData` object with inputs set.
 
     Notes
@@ -279,11 +359,10 @@ def run_step_from_dict(rtdata, **step_params):
         'args': list,              # The arguments passed to `Step.from_cmdline`
     }
     """
-
     # Get the data. If `step_params['input_path]` is not
     # specified, the presumption is that `rtdata.input` has
     # already been retrieved.
-    input_path = step_params.get('input_path', None)
+    input_path = step_params.get("input_path", None)
     if input_path:
         try:
             rtdata.get_asn(input_path)
@@ -291,14 +370,14 @@ def run_step_from_dict(rtdata, **step_params):
             rtdata.get_data(input_path)
 
     # Figure out whether we have a config or class
-    step = step_params['step']
-    if step.endswith(('.asdf', '.cfg')):
-        step = os.path.join('config', step)
+    step = step_params["step"]
+    if step.endswith((".asdf", ".cfg")):
+        step = os.path.join("config", step)
 
     # Run the step
-    collect_pipeline_cfgs('config')
+    collect_pipeline_cfgs("config")
     full_args = [step, rtdata.input]
-    full_args.extend(step_params['args'])
+    full_args.extend(step_params["args"])
 
     Step.from_cmdline(full_args)
 
@@ -306,25 +385,26 @@ def run_step_from_dict(rtdata, **step_params):
 
 
 def run_step_from_dict_mock(rtdata, source, **step_params):
-    """Pretend to run Steps with given parameter but just copy data
+    """
+    Pretend to run Steps with given parameter but just copy data.
 
     For long running steps where the result already exists, just
     copy the data from source
 
     Parameters
     ----------
-    rtdata: RegtestData
+    rtdata : RegtestData
         The artifactory instance
 
-    step_params: dict
-        The parameters defining what step to run with what input
-
-    source: Path-like folder
+    source : Path-like folder
         The folder to copy from. All regular files are copied.
 
+    **step_params : dict
+        The parameters defining what step to run with what input
+
     Returns
     -------
-    rtdata: RegtestData
+    rtdata : RegtestData
         Updated `RegtestData` object with inputs set.
 
     Notes
@@ -336,11 +416,10 @@ def run_step_from_dict_mock(rtdata, source, **step_params):
         'args': list,              # The arguments passed to `Step.from_cmdline`
     }
     """
-
     # Get the data. If `step_params['input_path]` is not
     # specified, the presumption is that `rtdata.input` has
     # already been retrieved.
-    input_path = step_params.get('input_path', None)
+    input_path = step_params.get("input_path", None)
     if input_path:
         try:
             rtdata.get_asn(input_path)
@@ -351,29 +430,30 @@ def run_step_from_dict_mock(rtdata, source, **step_params):
     for file_name in os.listdir(source):
         file_path = os.path.join(source, file_name)
         if os.path.isfile(file_path):
-            shutil.copy(file_path, '.')
+            shutil.copy(file_path, ".")
 
     return rtdata
 
 
 def is_like_truth(rtdata, fitsdiff_default_kwargs, output, truth_path, is_suffix=True):
-    """Compare step outputs with truth
+    """
+    Compare step outputs with truth.
 
     Parameters
     ----------
-    rtdata: RegtestData
+    rtdata : RegtestData
         The artifactory object from the step run.
 
-    fitsdiff_default_kwargs: dict
+    fitsdiff_default_kwargs : dict
         The `fitsdiff` keyword arguments
 
-    output: str
+    output : str
         The suffix or full file name to check on.
 
-    truth_path: str
+    truth_path : str
         Location of the truth files.
 
-    is_suffix: bool
+    is_suffix : bool
         Interpret `output` as just a suffix on the expected output root.
         Otherwise, assume it is a full file name
     """
@@ -384,10 +464,10 @@ def is_like_truth(rtdata, fitsdiff_default_kwargs, output, truth_path, is_suffix
     if is_suffix:
         suffix = output
         if rtdata.asn:
-            output = rtdata.asn['products'][0]['name']
+            output = rtdata.asn["products"][0]["name"]
         else:
             output = os.path.splitext(os.path.basename(rtdata.input))[0]
-        output = replace_suffix(output, suffix) + '.fits'
+        output = replace_suffix(output, suffix) + ".fits"
     rtdata.output = output
 
     rtdata.get_truth(os.path.join(truth_path, output))
@@ -397,19 +477,20 @@ def is_like_truth(rtdata, fitsdiff_default_kwargs, output, truth_path, is_suffix
 
 
 def text_diff(from_path, to_path):
-    """Assertion helper for diffing two text files
+    """
+    Diff two text files.
 
     Parameters
     ----------
-    from_path: str
+    from_path : str
         File to diff from.
 
-    to_path: str
+    to_path : str
         File to diff to.  The truth.
 
     Returns
     -------
-    diffs: [str[,...]]
+    diffs : [str[,...]]
         A generator of a list of strings that are the differences.
         The output from `difflib.unified_diff`
     """
@@ -419,7 +500,8 @@ def text_diff(from_path, to_path):
     with open(to_path) as fh:
         to_lines = fh.readlines()
 
-    diffs = unified_diff(from_lines, to_lines, from_path, to_path)
+    # convert path objects to strings because difflib requires strings
+    diffs = unified_diff(from_lines, to_lines, str(from_path), str(to_path))
 
     diff = list(diffs)
     if len(diff) > 0:
@@ -430,16 +512,17 @@ def text_diff(from_path, to_path):
 
 
 def _data_glob_local(*glob_parts):
-    """Perform a glob on the local path
+    """
+    Perform a glob on the local path.
 
     Parameters
     ----------
-    glob_parts: (path-like,[...])
+    *glob_parts : (path-like,[...])
         List of components that will be built into a single path
 
     Returns
     -------
-    file_paths: [str[, ...]]
+    file_paths : [str[, ...]]
         Full file paths that match the glob criterion
     """
     full_glob = Path().joinpath(*glob_parts)
@@ -448,54 +531,59 @@ def _data_glob_local(*glob_parts):
 
 def _data_glob_url(*url_parts, root=None):
     """
+    Perform a glob on a URL path.
+
     Parameters
     ----------
-    url: (str[,...])
+    *url_parts : (str[,...])
         List of components that will be used to create a URL path
 
-    root: str
+    root : str
         The root server path to the Artifactory server.
         Normally retrieved from `get_bigdata_root`.
 
     Returns
     -------
-    url_paths: [str[, ...]]
+    url_paths : [str[, ...]]
         Full URLS that match the glob criterion
     """
     # Fix root root-ed-ness
-    if root.endswith('/'):
+    if root.endswith("/"):
         root = root[:-1]
 
     # Access
     try:
-        envkey = os.environ['API_KEY_FILE']
+        envkey = os.environ["API_KEY_FILE"]
     except KeyError:
         envkey = ARTIFACTORY_API_KEY_FILE
 
     try:
         with open(envkey) as fp:
-            headers = {'X-JFrog-Art-Api': fp.readline().strip()}
+            headers = {"X-JFrog-Art-Api": fp.readline().strip()}
     except (PermissionError, FileNotFoundError):
-        print("Warning: Anonymous Artifactory search requests are limited to "
-              "1000 results. Use an API key and define API_KEY_FILE environment "
-              "variable to get full search results.", file=sys.stderr)
+        print(  # noqa: T201
+            "Warning: Anonymous Artifactory search requests are limited to "  # noqa: T201
+            "1000 results. Use an API key and define API_KEY_FILE environment "
+            "variable to get full search results.",
+            file=sys.stderr,
+        )
         headers = None
 
-    search_url = '/'.join([root, 'api/search/pattern'])
+    search_url = "/".join([root, "api/search/pattern"])
 
     # Join and re-split the url so that every component is identified.
-    url = '/'.join([root] + [idx for idx in url_parts])
-    all_parts = url.split('/')
+    url = "/".join([root] + list(url_parts))
+    all_parts = url.split("/")
 
     # Pick out "jwst-pipeline", the repo name
     repo = all_parts[4]
 
     # Format the pattern
-    pattern = repo + ':' + '/'.join(all_parts[5:])
+    pattern = repo + ":" + "/".join(all_parts[5:])
 
     # Make the query
-    params = {'pattern': pattern}
-    with requests.get(search_url, params=params, headers=headers) as r:
-        url_paths = r.json()['files']
+    params = {"pattern": pattern}
+    with requests.get(search_url, params=params, headers=headers, timeout=60) as r:
+        url_paths = r.json()["files"]
 
     return url_paths
