@@ -1,5 +1,5 @@
 import pytest
-from astropy.io.fits.diff import FITSDiff
+from jwst.regtest.st_fitsdiff import STFITSDiff as FITSDiff
 
 from jwst.stpipe import Step
 
@@ -7,20 +7,23 @@ from jwst.stpipe import Step
 @pytest.fixture(scope="module")
 def run_fgs_image2(rtdata_module):
     rtdata = rtdata_module
-    rtdata.get_data("fgs/image2/jw86500007001_02101_00001_GUIDER2_rate.fits")
+    rtdata.get_data("fgs/image2/jw01029001001_04201_00001_guider2_rate.fits")
 
-    args = ["calwebb_image2", rtdata.input,
-            "--steps.flat_field.save_results=True",
-            "--steps.resample.save_results=True"]
+    args = [
+        "calwebb_image2",
+        rtdata.input,
+        "--steps.flat_field.save_results=True",
+        "--steps.resample.save_results=True",
+    ]
     Step.from_cmdline(args)
 
 
 @pytest.mark.bigdata
-@pytest.mark.parametrize("suffix", ['flat_field', 'cal', 'i2d'])
+@pytest.mark.parametrize("suffix", ["flat_field", "cal", "i2d"])
 def test_fgs_image2(run_fgs_image2, rtdata_module, fitsdiff_default_kwargs, suffix):
     """Regression test for FGS data in the image2 pipeline"""
     rtdata = rtdata_module
-    output = f"jw86500007001_02101_00001_GUIDER2_{suffix}.fits"
+    output = f"jw01029001001_04201_00001_guider2_{suffix}.fits"
     rtdata.output = output
 
     rtdata.get_truth(f"truth/test_fgs_image2/{output}")
