@@ -1,46 +1,69 @@
-from astropy.io.fits.diff import FITSDiff
+from jwst.regtest.st_fitsdiff import STFITSDiff as FITSDiff
 from gwcs.wcstools import grid_from_bounding_box
 from numpy.testing import assert_allclose
 import pytest
 
+from stdatamodels.jwst import datamodels
+
 from jwst.stpipe import Step
-from jwst import datamodels
 from jwst.extract_1d import Extract1dStep
+from stcal.alignment import util
+
+# Mark all tests in this module
+pytestmark = [pytest.mark.bigdata]
 
 
 @pytest.fixture(scope="module")
-def run_pipeline(jail, rtdata_module):
+def run_pipeline(rtdata_module, resource_tracker):
     """Run the calwebb_spec2 pipeline on an ASN of nodded MIRI LRS
-       fixedslit exposures."""
+    fixedslit exposures."""
     rtdata = rtdata_module
 
     # Get the spec2 ASN and its members
-    rtdata.get_data("miri/lrs/MIRI_FM_MIRIMAGE_P750L_PATHLOSS_8C.00.00.fits")
-    rtdata.get_asn("miri/lrs/jw00623-o032_20191210t195246_spec2_001_asn.json")
+    rtdata.get_asn("miri/lrs/jw01530-o005_20221202t204827_spec2_00001_asn.json")
 
     # Run the calwebb_spec2 pipeline; save results from intermediate steps
-    args = ["calwebb_spec2", rtdata.input,
-            "--save_bsub=true",
-            "--steps.assign_wcs.save_results=true",
-            "--steps.flat_field.save_results=true",
-            "--steps.srctype.save_results=true",
-            "--steps.pathloss.save_results=true",
-            "--steps.pathloss.override_pathloss=MIRI_FM_MIRIMAGE_P750L_PATHLOSS_8C.00.00.fits",
-            "--steps.bkg_subtract.save_combined_background=true"
-            ]
-    Step.from_cmdline(args)
+    args = [
+        "calwebb_spec2",
+        rtdata.input,
+        "--steps.assign_wcs.save_results=true",
+        "--save_bsub=true",
+        "--steps.srctype.save_results=true",
+        "--steps.flat_field.save_results=true",
+        "--steps.pathloss.save_results=true",
+        "--steps.pixel_replace.skip=false",
+        "--steps.pixel_replace.save_results=true",
+        "--steps.bkg_subtract.save_combined_background=true",
+    ]
+    with resource_tracker.track():
+        Step.from_cmdline(args)
 
 
-@pytest.mark.bigdata
-@pytest.mark.parametrize("suffix", [
-    "bsub", "flat_field", "assign_wcs", "srctype", "pathloss",
-    "combinedbackground", "cal", "s2d", "x1d"])
+def test_log_tracked_resources_spec2(log_tracked_resources, run_pipeline):
+    log_tracked_resources()
+
+
+@pytest.mark.parametrize(
+    "suffix",
+    [
+        "assign_wcs",
+        "combinedbackground",
+        "bsub",
+        "srctype",
+        "flat_field",
+        "pathloss",
+        "cal",
+        "pixel_replace",
+        "s2d",
+        "x1d",
+    ],
+)
 def test_miri_lrs_slit_spec2(run_pipeline, fitsdiff_default_kwargs, suffix, rtdata_module):
     """Regression test of the calwebb_spec2 pipeline on MIRI
-       LRS fixedslit data using along-slit-nod pattern for
-       background subtraction."""
+    LRS fixedslit data using along-slit-nod pattern for
+    background subtraction."""
     rtdata = rtdata_module
-    output = f"jw00623032001_03102_00001_mirimage_{suffix}.fits"
+    output = f"jw01530005001_03103_00001_mirimage_{suffix}.fits"
     rtdata.output = output
 
     # Get the truth files
@@ -51,42 +74,21 @@ def test_miri_lrs_slit_spec2(run_pipeline, fitsdiff_default_kwargs, suffix, rtda
     assert diff.identical, diff.report()
 
 
-@pytest.mark.bigdata
 def test_miri_lrs_extract1d_from_cal(run_pipeline, rtdata_module, fitsdiff_default_kwargs):
     rtdata = rtdata_module
-    rtdata.input = "jw00623032001_03102_00001_mirimage_cal.fits"
+    rtdata.input = "jw01530005001_03103_00001_mirimage_cal.fits"
     Extract1dStep.call(rtdata.input, save_results=True)
-    output = "jw00623032001_03102_00001_mirimage_extract1dstep.fits"
+    output = "jw01530005001_03103_00001_mirimage_extract1dstep.fits"
     rtdata.output = output
     rtdata.get_truth(f"truth/test_miri_lrs_slit_spec2/{output}")
     diff = FITSDiff(rtdata.output, rtdata.truth, **fitsdiff_default_kwargs)
     assert diff.identical, diff.report()
 
 
-@pytest.mark.bigdata
-def test_miri_lrs_extract1d_image_ref(run_pipeline, rtdata_module, fitsdiff_default_kwargs):
-    rtdata = rtdata_module
-
-    rtdata.get_data("miri/lrs/jw00623032001_03102_00001_mirimage_image_ref.fits")
-    rtdata.input = "jw00623032001_03102_00001_mirimage_cal.fits"
-    Extract1dStep.call(rtdata.input,
-                       override_extract1d="jw00623032001_03102_00001_mirimage_image_ref.fits",
-                       suffix='x1dfromrefimage',
-                       save_results=True)
-    output = "jw00623032001_03102_00001_mirimage_x1dfromrefimage.fits"
-    rtdata.output = output
-    rtdata.get_truth(f"truth/test_miri_lrs_slit_spec2/{output}")
-
-    diff = FITSDiff(rtdata.output, rtdata.truth, **fitsdiff_default_kwargs)
-    assert diff.identical, diff.report()
-
-
-@pytest.mark.bigdata
 def test_miri_lrs_slit_wcs(run_pipeline, rtdata_module, fitsdiff_default_kwargs):
     rtdata = rtdata_module
-
     # get input assign_wcs and truth file
-    output = "jw00623032001_03102_00001_mirimage_assign_wcs.fits"
+    output = "jw01530005001_03103_00001_mirimage_assign_wcs.fits"
     rtdata.output = output
     rtdata.get_truth(f"truth/test_miri_lrs_slit_spec2/{output}")
 
@@ -104,3 +106,11 @@ def test_miri_lrs_slit_wcs(run_pipeline, rtdata_module, fitsdiff_default_kwargs)
         xtruth, ytruth = im_truth.meta.wcs.backward_transform(ratruth, dectruth, lamtruth)
         assert_allclose(xtest, xtruth)
         assert_allclose(ytest, ytruth)
+
+        # Test the s_region. S_region is formed by footprint which contains
+        # floats rather than a string. Test footprint
+        sregion = im.meta.wcsinfo.s_region
+        sregion_test = im_truth.meta.wcsinfo.s_region
+        footprint = util.sregion_to_footprint(sregion)
+        footprint_test = util.sregion_to_footprint(sregion_test)
+        assert_allclose(footprint, footprint_test)
