@@ -1,4 +1,6 @@
+"""Apply resampling to JWST data."""
+
 from .resample_step import ResampleStep
 from .resample_spec_step import ResampleSpecStep
 
-__all__ = ['ResampleStep', 'ResampleSpecStep']
+__all__ = ["ResampleStep", "ResampleSpecStep"]
