@@ -1,12 +1,9 @@
-"""
-This package provides support for sky background subtraction and equalization
-(matching).
+"""Provide support for sky background subtraction and equalization (matching)."""
 
-"""
 import logging
 from .skymatch_step import SkyMatchStep
 
-__author__ = 'Mihai Cara'
+__author__ = "Mihai Cara"
 
 
 log = logging.getLogger(__name__)
