@@ -6,21 +6,19 @@ log.setLevel(logging.DEBUG)
 
 
 class DummyStep(Step):
-    """
-    This is a dummy step that does dumb things.
-    """
+    """Placeholder step."""
 
     spec = """
     foo = string()
     """
 
-    def process(self, *args):
-        from jwst.datamodels import ImageModel
+    def process(self, *args):  # noqa: D102
+        from stdatamodels.jwst.datamodels import ImageModel
 
         log.info("Default logger")
         log.debug("Default logger")
 
-        self.log.info("Foo: {0}".format(self.foo))
+        self.log.info(f"Foo: {self.foo}")
 
         self.log.debug("Debug!!!")
 
