@@ -6,7 +6,8 @@ import pytest
 
 from stpipe import crds_client
 
-from jwst import datamodels
+from stdatamodels.jwst import datamodels
+
 from jwst.stpipe import Step, Pipeline
 
 from jwst.stpipe.tests.steps import PipeWithReference, StepWithReference
@@ -14,6 +15,7 @@ from jwst.stpipe.tests.steps import PipeWithReference, StepWithReference
 
 def library_function():
     import logging
+
     log = logging.getLogger(__name__)
     log.info("This is a library function log")
 
@@ -22,6 +24,7 @@ class FlatField(Step):
     """
     An example flat-fielding Step.
     """
+
     spec = """
         threshold = float(default=0.0)  # The threshold below which to remove
         multiplier = float(default=1.0) # Multiply by this number
@@ -76,11 +79,7 @@ class MyPipeline(Pipeline):
     A test pipeline.
     """
 
-    step_defs = {
-        'flat_field': FlatField,
-        'combine': Combine,
-        'display': Display
-    }
+    step_defs = {"flat_field": FlatField, "combine": Combine, "display": Display}
 
     spec = """
     science_filename = input_file()  # The input science filename
@@ -93,9 +92,9 @@ class MyPipeline(Pipeline):
             self.flat_filename = join(dirname(__file__), "data", "flat.fits")
         flat = datamodels.open(self.flat_filename)
         calibrated = []
-        calibrated.append(self.flat_field(science, flat))
-        combined = self.combine(calibrated)
-        self.display(combined)
+        calibrated.append(self.flat_field.run(science, flat))
+        combined = self.combine.run(calibrated)
+        self.display.run(combined)
         dm = datamodels.ImageModel(combined)
         self.save_model(dm)
         science.close()
@@ -103,8 +102,8 @@ class MyPipeline(Pipeline):
         return dm
 
 
-def test_pipeline_from_config_file(_jail):
-    config_file_path = join(dirname(__file__), 'steps', 'python_pipeline.cfg')
+def test_pipeline_from_config_file(tmp_cwd):
+    config_file_path = join(dirname(__file__), "steps", "python_pipeline.cfg")
     pipe = Pipeline.from_config_file(config_file_path)
 
     assert pipe.flat_field.threshold == 42.0
@@ -113,17 +112,16 @@ def test_pipeline_from_config_file(_jail):
     pipe.run()
 
 
-def test_pipeline_python(_jail):
-    steps = {
-        'flat_field': {'threshold': 42.0}
-    }
+def test_pipeline_python(tmp_cwd):
+    steps = {"flat_field": {"threshold": 42.0}}
 
     pipe = MyPipeline(
         "MyPipeline",
         steps=steps,
-        science_filename=abspath(join(dirname(__file__), 'data', 'science.fits')),
-        flat_filename=abspath(join(dirname(__file__), 'data', 'flat.fits')),
-        output_file="python.fits")
+        science_filename=abspath(join(dirname(__file__), "data", "science.fits")),
+        flat_filename=abspath(join(dirname(__file__), "data", "flat.fits")),
+        output_file="python.fits",
+    )
 
     assert pipe.flat_field.threshold == 42.0
     assert pipe.flat_field.multiplier == 1.0
@@ -131,7 +129,7 @@ def test_pipeline_python(_jail):
     pipe.run()
 
 
-def test_prefetch(_jail, monkeypatch):
+def test_prefetch(tmp_cwd, monkeypatch):
     """Test prefetching"""
 
     # Setup mock to crds to flag if the call was made.
@@ -139,23 +137,22 @@ def test_prefetch(_jail, monkeypatch):
         called = False
 
         def mock(self, parameters, reference_file_types, observatory):
-            if 'flat' in reference_file_types:
+            if "flat" in reference_file_types:
                 self.called = True
-            result = {
-                reftype: 'N/A'
-                for reftype in reference_file_types
-            }
+            result = {reftype: "N/A" for reftype in reference_file_types}
             return result
+
         __call__ = mock
+
     mock_get_ref = MockGetRef()
-    monkeypatch.setattr(crds_client, 'get_multiple_reference_paths', mock_get_ref)
+    monkeypatch.setattr(crds_client, "get_multiple_reference_paths", mock_get_ref)
 
     # Create some data
     model = datamodels.ImageModel((19, 19))
     model.meta.instrument.name = "NIRCAM"
-    model.meta.instrument.detector = 'NRCA1'
+    model.meta.instrument.detector = "NRCA1"
     model.meta.instrument.filter = "F070W"
-    model.meta.instrument.pupil = 'CLEAR'
+    model.meta.instrument.pupil = "CLEAR"
     model.meta.observation.date = "2019-01-01"
     model.meta.observation.time = "00:00:00"
 
@@ -171,10 +168,10 @@ def test_prefetch(_jail, monkeypatch):
     assert not mock_get_ref.called
 
 
-def test_pipeline_from_cmdline_cfg(_jail):
+def test_pipeline_from_cmdline_cfg(tmp_cwd):
     args = [
-        join(dirname(__file__), 'steps', 'python_pipeline.cfg'),
-        '--steps.flat_field.threshold=47',
+        join(dirname(__file__), "steps", "python_pipeline.cfg"),
+        "--steps.flat_field.threshold=47",
     ]
 
     pipe = Step.from_cmdline(args)
@@ -185,12 +182,12 @@ def test_pipeline_from_cmdline_cfg(_jail):
     pipe.run()
 
 
-def test_pipeline_from_cmdline_class(_jail):
+def test_pipeline_from_cmdline_class(tmp_cwd):
     args = [
-        'jwst.stpipe.tests.test_pipeline.MyPipeline',
+        "jwst.stpipe.tests.test_pipeline.MyPipeline",
         f"--science_filename={join(dirname(__file__), 'data', 'science.fits')}",
-        '--output_file=output.fits',
-        '--steps.flat_field.threshold=47'
+        "--output_file=output.fits",
+        "--steps.flat_field.threshold=47",
     ]
 
     pipe = Step.from_cmdline(args)
@@ -205,13 +202,12 @@ def test_pipeline_commandline_invalid_args():
     from io import StringIO
 
     args = [
-        'jwst.stpipe.tests.test_pipeline.MyPipeline',
+        "jwst.stpipe.tests.test_pipeline.MyPipeline",
         # The file_name parameters are *required*, and one of them
         # is missing, so we should get a message to that effect
         # followed by the commandline usage message.
-        '--flat_filename={0}'.format(
-            abspath(join(dirname(__file__), 'data', 'flat.fits'))),
-        '--steps.flat_field.threshold=47'
+        "--flat_filename={0}".format(abspath(join(dirname(__file__), "data", "flat.fits"))),
+        "--steps.flat_field.threshold=47",
     ]
 
     sys.stdout = buffer = StringIO()
