@@ -1,6 +1,7 @@
 import pytest
 
-from jwst import datamodels
+from stdatamodels.jwst import datamodels
+
 from jwst.assign_wcs import AssignWcsStep
 from jwst.associations.asn_from_list import asn_from_list
 from jwst.wfs_combine import WfsCombineStep
@@ -14,7 +15,7 @@ SATURATED = datamodels.dqflags.pixel["SATURATED"]
 
 
 def gaussian(x, mu, sig):
-    return 1. / (np.sqrt(2 * np.pi) * sig) * np.exp(-np.power((x - mu) / sig, 2) / 2)
+    return 1.0 / (np.sqrt(2 * np.pi) * sig) * np.exp(-np.power((x - mu) / sig, 2) / 2)
 
 
 def gaussian2d(x, y, mux, muy, sigx, sigy):
@@ -26,9 +27,9 @@ def add_point_source(inarray, scale, xcen, ycen, sigx, sigy):
     for y in range(inarray.shape[0]):
         for x in range(inarray.shape[1]):
             outarray[y, x] = scale * gaussian2d(x, y, xcen, ycen, sigx, sigy)
-#            outarray[y, x] = modeling.functional_models.Gaussian2D(amplitude=scale,
-#                                                                   x_mean=xcen, y_mean=ycen,
-#                                                                   x_stddev=sigx, y_stddev=sigy)
+    #            outarray[y, x] = modeling.functional_models.Gaussian2D(amplitude=scale,
+    #                                                                   x_mean=xcen, y_mean=ycen,
+    #                                                                   x_stddev=sigx, y_stddev=sigy)
     return outarray
 
 
@@ -38,42 +39,40 @@ def wfs_association(tmp_path_factory):
     tmp_path = tmp_path_factory.mktemp("wfs")
     im1 = datamodels.ImageModel((imsize, imsize))
     im1.meta.wcsinfo = {
-        'dec_ref': 11.99875540218638,
-        'ra_ref': 22.02351763251896,
-        'roll_ref': 0.005076934167039675,
-        'v2_ref': 86.039011,
-        'v3_ref': -493.385704,
-        'v3yangle': -0.07385127,
-        'vparity': -1,
-        'wcsaxes': 2}
+        "dec_ref": 11.99875540218638,
+        "ra_ref": 22.02351763251896,
+        "roll_ref": 0.005076934167039675,
+        "v2_ref": 86.039011,
+        "v3_ref": -493.385704,
+        "v3yangle": -0.07385127,
+        "vparity": -1,
+        "wcsaxes": 2,
+    }
     im1.meta.instrument = {
-        'channel': 'SHORT',
-        'detector': 'NRCA4',
-        'filter': 'F212N',
-        'module': 'A',
-        'name': 'NIRCAM',
-        'pupil': 'CLEAR'}
-    im1.meta.observation = {
-        'exposure_number': '1',
-        'date': '2021-10-25',
-        'time': '16:58:27.258'}
-    im1.meta.exposure = {
-        'type': 'NRC_IMAGE'}
+        "channel": "SHORT",
+        "detector": "NRCA4",
+        "filter": "F212N",
+        "module": "A",
+        "name": "NIRCAM",
+        "pupil": "CLEAR",
+    }
+    im1.meta.observation = {"exposure_number": "1", "date": "2021-10-25", "time": "16:58:27.258"}
+    im1.meta.exposure = {"type": "NRC_IMAGE"}
 
     im1 = AssignWcsStep.call(im1, sip_approx=False)
 
     im2 = im1.copy()
-    im2.meta.observation = {
-        'exposure_number': '2',
-        'date': '2021-10-25',
-        'time': '17:58:27.258'}
+    im2.meta.observation = {"exposure_number": "2", "date": "2021-10-25", "time": "17:58:27.258"}
     path1 = str(tmp_path / "image1_cal.fits")
     path2 = str(tmp_path / "image2_cal.fits")
     im1.save(path1)
     im2.save(path2)
 
-    asn = asn_from_list([path1, path2],
-                        product_name='jw00024-a3001_t001_nircam_nrca4_{suffix}')
+    # asn = asn_from_list([path1, path2],
+    asn = asn_from_list(
+        ["image1_cal.fits", "image2_cal.fits"],
+        product_name="jw00024-a3001_t001_nircam_nrca4_{suffix}",
+    )
     asn.data["program"] = "00024"
     asn.data["asn_type"] = "wfs-image2"
     asn.sequence = 1
@@ -97,10 +96,9 @@ def wfs_association(tmp_path_factory):
         (1, 3, GOOD, DO_NOT_USE + SATURATED, 1, GOOD),
         (1, 3, DO_NOT_USE, DO_NOT_USE + SATURATED, 0, DO_NOT_USE),
         (1, 3, SATURATED, SATURATED, 2, SATURATED),
-    ]
+    ],
 )
-def test_create_combined(_jail, wfs_association,
-                         data1, data2, dq1, dq2, result_data, result_dq):
+def test_create_combined(tmp_cwd, wfs_association, data1, data2, dq1, dq2, result_data, result_dq):
     path_asn, path1, path2 = wfs_association
 
     # Populate data and DQ array at [5, 5] with what is to be tested
@@ -114,8 +112,9 @@ def test_create_combined(_jail, wfs_association,
         im1.save(path1)
         im2.save(path2)
 
-    result = WfsCombineStep.call(path_asn, do_refine=False, flip_dithers=False, psf_size=50,
-                                 blur_size=10, n_size=2)
+    result = WfsCombineStep.call(
+        path_asn, do_refine=False, flip_dithers=False, psf_size=50, blur_size=10, n_size=2
+    )
 
     # Check that results are as expected
     assert result[0].data[5, 5] == result_data
@@ -124,22 +123,35 @@ def test_create_combined(_jail, wfs_association,
 
 def test_shift_order_no_refine_no_flip(wfs_association):
     path_asn, path1, path2 = wfs_association
-    nircam_pixel_size = 0.031 / 3600.
+    nircam_pixel_size = 0.031 / 3600.0
     delta_pixel = 5
     with datamodels.open(path2) as im2:
         im2.meta.wcsinfo = {
-            'dec_ref': 11.99875540218638,
-            'ra_ref': 22.02351763251896 + delta_pixel * nircam_pixel_size,
-            'roll_ref': 0.005076934167039675, 'v2_ref': 86.039011, 'v3_ref': -493.385704,
-            'v3yangle': -0.07385127, 'vparity': -1, 'wcsaxes': 2}
+            "dec_ref": 11.99875540218638,
+            "ra_ref": 22.02351763251896 + delta_pixel * nircam_pixel_size,
+            "roll_ref": 0.005076934167039675,
+            "v2_ref": 86.039011,
+            "v3_ref": -493.385704,
+            "v3yangle": -0.07385127,
+            "vparity": -1,
+            "wcsaxes": 2,
+        }
         im2 = AssignWcsStep.call(im2, sip_approx=False)
 
         im2.save(path2)
-    wfs = wfs_combine.DataSet(path1, path2, 'outfile.fits', do_refine=False, flip_dithers=False, psf_size=50,
-                              blur_size=10, n_size=2)
+    wfs = wfs_combine.DataSet(
+        path1,
+        path2,
+        "outfile.fits",
+        do_refine=False,
+        flip_dithers=False,
+        psf_size=50,
+        blur_size=10,
+        n_size=2,
+    )
     wfs.do_all()
-    assert wfs.input_1.meta.observation.exposure_number == '1'
-    assert wfs.input_2.meta.observation.exposure_number == '2'
+    assert wfs.input_1.meta.observation.exposure_number == "1"
+    assert wfs.input_2.meta.observation.exposure_number == "2"
     assert wfs.off_x == abs(delta_pixel)
     assert wfs.off_y == 0
     wfs.input_1.close()
@@ -150,23 +162,36 @@ def test_shift_order_no_refine_with_flip(wfs_association):
     # change the sign of the the dither and check that we get the same delta pix but with switched
     # order of images.
     path_asn, path1, path2 = wfs_association
-    nircam_pixel_size = 0.031 / 3600.
+    nircam_pixel_size = 0.031 / 3600.0
     delta_pixel = -5
     with datamodels.open(path2) as im2:
         im2.meta.wcsinfo = {
-            'dec_ref': 11.99875540218638,
-            'ra_ref': 22.02351763251896 + delta_pixel * nircam_pixel_size,
-            'roll_ref': 0.005076934167039675, 'v2_ref': 86.039011, 'v3_ref': -493.385704,
-            'v3yangle': -0.07385127, 'vparity': -1, 'wcsaxes': 2}
+            "dec_ref": 11.99875540218638,
+            "ra_ref": 22.02351763251896 + delta_pixel * nircam_pixel_size,
+            "roll_ref": 0.005076934167039675,
+            "v2_ref": 86.039011,
+            "v3_ref": -493.385704,
+            "v3yangle": -0.07385127,
+            "vparity": -1,
+            "wcsaxes": 2,
+        }
         im2 = AssignWcsStep.call(im2, sip_approx=False)
         im2.save(path2)
-    wfs = wfs_combine.DataSet(path1, path2, 'outfile.fits', do_refine=False, flip_dithers=True, psf_size=50,
-                              blur_size=10, n_size=2)
+    wfs = wfs_combine.DataSet(
+        path1,
+        path2,
+        "outfile.fits",
+        do_refine=False,
+        flip_dithers=True,
+        psf_size=50,
+        blur_size=10,
+        n_size=2,
+    )
     wfs.do_all()
     wfs.input_1.close()
     wfs.input_2.close()
-#    assert wfs.input_1.meta.observation.exposure_number == '2'
-#    assert wfs.input_2.meta.observation.exposure_number == '1'
+    #    assert wfs.input_1.meta.observation.exposure_number == '2'
+    #    assert wfs.input_2.meta.observation.exposure_number == '1'
     assert wfs.off_x == -1 * delta_pixel
 
 
@@ -197,12 +222,12 @@ def test_shift_order_no_refine_with_flip(wfs_association):
         (5, -5, 1, -1, False),
         (-5, -5, 1, -1, False),
         (-5, 5, -1, 1, False),
-    ]
+    ],
 )
 def test_refine_no_error(wfs_association, xshift, yshift, xerror, yerror, flip_dithers):
     data_size = 201
     path_asn, path1, path2 = wfs_association
-    nircam_pixel_size = 0.031 / 3600.
+    nircam_pixel_size = 0.031 / 3600.0
     delta_x_pixel = xshift
     # positive y pixel changes are negative declination changes
     delta_y_pixel = -1.0 * yshift
@@ -215,16 +240,31 @@ def test_refine_no_error(wfs_association, xshift, yshift, xerror, yerror, flip_d
         im2.data = np.zeros(shape=(data_size, data_size), dtype=np.float32)
         im2.dq = np.zeros(shape=(data_size, data_size), dtype=np.int32)
         im2.meta.wcsinfo = {
-            'dec_ref': 11.99875540218638 + delta_y_pixel * nircam_pixel_size,
-            'ra_ref': 22.02351763251896 + delta_x_pixel * nircam_pixel_size,
-            'roll_ref': 0.005076934167039675, 'v2_ref': 86.039011, 'v3_ref': -493.385704,
-            'v3yangle': -0.07385127, 'vparity': -1, 'wcsaxes': 2}
+            "dec_ref": 11.99875540218638 + delta_y_pixel * nircam_pixel_size,
+            "ra_ref": 22.02351763251896 + delta_x_pixel * nircam_pixel_size,
+            "roll_ref": 0.005076934167039675,
+            "v2_ref": 86.039011,
+            "v3_ref": -493.385704,
+            "v3yangle": -0.07385127,
+            "vparity": -1,
+            "wcsaxes": 2,
+        }
         im2 = AssignWcsStep.call(im2, sip_approx=False)
         # shift the actual location of the 2nd image including the error in the WCS position
-        im2.data = add_point_source(im2.data, 200, 100 + delta_x_pixel + xerror, 100 + delta_y_pixel - yerror, 4, 4)
+        im2.data = add_point_source(
+            im2.data, 200, 100 + delta_x_pixel + xerror, 100 + delta_y_pixel - yerror, 4, 4
+        )
         im2.save(path2)
-    wfs = wfs_combine.DataSet(path1, path2, 'outfile.fits', do_refine=True, flip_dithers=flip_dithers, psf_size=50,
-                              blur_size=10, n_size=2)
+    wfs = wfs_combine.DataSet(
+        path1,
+        path2,
+        "outfile.fits",
+        do_refine=True,
+        flip_dithers=flip_dithers,
+        psf_size=50,
+        blur_size=10,
+        n_size=2,
+    )
     wfs.do_all()
     assert np.max(abs(wfs.diff)) < 0.001
     if delta_x_pixel + xerror >= 0 or not flip_dithers:
@@ -242,7 +282,7 @@ def test_refine_no_error(wfs_association, xshift, yshift, xerror, yerror, flip_d
 def test_refine_with_error(wfs_association):
     data_size = 201
     path_asn, path1, path2 = wfs_association
-    nircam_pixel_size = 0.031 / 3600.
+    nircam_pixel_size = 0.031 / 3600.0
     shift_error = 2
     delta_pixel = 5
     with datamodels.open(path1) as im1:
@@ -251,19 +291,32 @@ def test_refine_with_error(wfs_association):
         im1.save(path1)
     with datamodels.open(path2) as im2:
         im2.meta.wcsinfo = {
-            'dec_ref': 11.99875540218638,
-            'ra_ref': 22.02351763251896 + delta_pixel * nircam_pixel_size,
-            'roll_ref': 0.005076934167039675, 'v2_ref': 86.039011, 'v3_ref': -493.385704,
-            'v3yangle': -0.07385127, 'vparity': -1, 'wcsaxes': 2}
+            "dec_ref": 11.99875540218638,
+            "ra_ref": 22.02351763251896 + delta_pixel * nircam_pixel_size,
+            "roll_ref": 0.005076934167039675,
+            "v2_ref": 86.039011,
+            "v3_ref": -493.385704,
+            "v3yangle": -0.07385127,
+            "vparity": -1,
+            "wcsaxes": 2,
+        }
         im2 = AssignWcsStep.call(im2, sip_approx=False)
         im2.data = np.zeros(shape=(data_size, data_size), dtype=np.float32)
         im2.data = add_point_source(im2.data, 200, 100 + delta_pixel + shift_error, 100, 4, 4)
         im2.save(path2)
-    wfs = wfs_combine.DataSet(path1, path2, 'outfile.fits', do_refine=True, flip_dithers=True, psf_size=50,
-                              blur_size=10, n_size=2)
+    wfs = wfs_combine.DataSet(
+        path1,
+        path2,
+        "outfile.fits",
+        do_refine=True,
+        flip_dithers=True,
+        psf_size=50,
+        blur_size=10,
+        n_size=2,
+    )
     wfs.do_all()
-    assert wfs.input_1.meta.observation.exposure_number == '1'
-    assert wfs.input_2.meta.observation.exposure_number == '2'
+    assert wfs.input_1.meta.observation.exposure_number == "1"
+    assert wfs.input_2.meta.observation.exposure_number == "2"
     assert wfs.off_x == delta_pixel + shift_error
     assert wfs.off_y == 0
     wfs.input_1.close()
