@@ -1,7 +1,7 @@
 #! /usr/bin/env python
+from stdatamodels.jwst import datamodels
 
-from ..stpipe import Step
-from .. import datamodels
+from jwst.stpipe import Step
 from . import wfss_contam
 
 
@@ -9,9 +9,7 @@ __all__ = ["WfssContamStep"]
 
 
 class WfssContamStep(Step):
-    """
-    This Step performs contamination correction of WFSS spectra.
-    """
+    """Perform contamination correction of WFSS spectra."""
 
     class_alias = "wfss_contam"
 
@@ -20,30 +18,40 @@ class WfssContamStep(Step):
         save_contam_images = boolean(default=False)  # Save source contam estimates
         maximum_cores = option('none', 'quarter', 'half', 'all', default='none')
         skip = boolean(default=True)
-    """
+    """  # noqa: E501
 
-    reference_file_types = ['photom', 'wavelengthrange']
+    reference_file_types = ["photom", "wavelengthrange"]
 
-    def process(self, input_model, *args, **kwargs):
+    def process(self, input_model):
+        """
+        Run the WFSS contamination correction step.
 
+        Parameters
+        ----------
+        input_model : `~jwst.datamodels.MultiSlitModel`
+            The input data model containing 2-D cutouts for each identified source.
+
+        Returns
+        -------
+        output_model : `~jwst.datamodels.MultiSlitModel`
+            A copy of the input_model with contamination removed
+        """
         with datamodels.open(input_model) as dm:
-
             max_cores = self.maximum_cores
 
             # Get the wavelengthrange ref file
-            waverange_ref = self.get_reference_file(dm, 'wavelengthrange')
-            self.log.info(f'Using WAVELENGTHRANGE reference file {waverange_ref}')
+            waverange_ref = self.get_reference_file(dm, "wavelengthrange")
+            self.log.info(f"Using WAVELENGTHRANGE reference file {waverange_ref}")
             waverange_model = datamodels.WavelengthrangeModel(waverange_ref)
 
             # Get the photom ref file
-            photom_ref = self.get_reference_file(dm, 'photom')
-            self.log.info(f'Using PHOTOM reference file {photom_ref}')
+            photom_ref = self.get_reference_file(dm, "photom")
+            self.log.info(f"Using PHOTOM reference file {photom_ref}")
             photom_model = datamodels.open(photom_ref)
 
-            result, simul, contam = wfss_contam.contam_corr(dm,
-                                                            waverange_model,
-                                                            photom_model,
-                                                            max_cores)
+            result, simul, contam = wfss_contam.contam_corr(
+                dm, waverange_model, photom_model, max_cores
+            )
 
             # Save intermediate results, if requested
             if self.save_simulated_image:
